@@ -1,4 +1,4 @@
-<?PHP //$Id: backup_scheduled.php,v 1.14 2004/05/20 15:17:39 stronk7 Exp $
+<?PHP //$Id: backup_scheduled.php,v 1.16.2.4 2005/01/10 21:46:21 mjollnir_ Exp $
     //This file contains all the code needed to execute scheduled backups
 
 //This function is executed via moodle cron
@@ -13,7 +13,7 @@ function schedule_backup_cron() {
 
     //Check for required functions...
     if(!function_exists('utf8_encode')) {
-        echo "        ERROR: You need to add XML support to your PHP installation!\n";
+        mtrace("        ERROR: You need to add XML support to your PHP installation!");
         return true;
     }
 
@@ -22,13 +22,13 @@ function schedule_backup_cron() {
 
     //First of all, we have to see if the scheduled is active and detect
     //that there isn't another cron running
-    echo "    Checking backup status";
+    mtrace("    Checking backup status",'...');
     $backup_config = backup_get_config();
     if(!isset($backup_config->backup_sche_active) || !$backup_config->backup_sche_active) {
-        echo "...INACTIVE\n";
+        mtrace("INACTIVE");
         return true;
     } else if (isset($backup_config->backup_sche_running) && $backup_config->backup_sche_running) {
-        echo "...RUNNING\n";
+        mtrace("RUNNING");
         //Now check if it's a really running task or something very old looking 
         //for info in backup_logs to unlock status as necessary
         $timetosee = 1800;   //Half an hour looking for activity
@@ -36,33 +36,55 @@ function schedule_backup_cron() {
         $numofrec = count_records_select ("backup_log","time > $timeafter");
         if (!$numofrec) {
             $timetoseemin = $timetosee/60;
-            echo "    No activity in last ".$timetoseemin." minutes. Unlocking status\n";
+            mtrace("    No activity in last ".$timetoseemin." minutes. Unlocking status");
         } else {
-            echo "    Scheduled backup seems to be running. Execution delayed\n";
+            mtrace("    Scheduled backup seems to be running. Execution delayed");
             return true;
         }
     } else {
-        echo "...OK\n";
+        mtrace("OK");
         //Mark backup_sche_running
         backup_set_config("backup_sche_running","1");
     }
 
     //Now we get the main admin user (we'll use his timezone, mail...)
-    echo "    Getting admin info\n";
+    mtrace("    Getting admin info");
     $admin = get_admin();
     if (!$admin) {
         $status = false;
     }
 
+    //Delete old_entries from backup tables
+    if ($status) {
+        mtrace("    Deleting old data");
+        $status = backup_delete_old_data();
+    }
+
     //Now we get a list of courses in the server
     if ($status) {
-        echo "    Checking courses\n";
+        mtrace("    Checking courses");
+        //First of all, we delete everything from backup tables related to deleted courses
+        mtrace("        Skipping deleted courses");
+        $skipped = 0;
+        if ($bckcourses = get_records('backup_courses')) {
+            foreach($bckcourses as $bckcourse) {
+                //Search if it exists
+                if (!$exists = get_record('course', 'id', "$bckcourse->courseid")) {
+                    //Doesn't exist, so delete from backup tables
+                    delete_records('backup_courses', 'courseid', "$bckcourse->courseid");
+                    delete_records('backup_log', 'courseid', "$bckcourse->courseid");
+                    $skipped++;
+                }
+            }
+        }
+        mtrace("            $skipped courses");
+        //Now process existing courses
         $courses = get_records("course");
         //For each course, we check (insert, update) the backup_course table
         //with needed data
         foreach ($courses as $course) {
             if ($status) {
-                echo "        $course->fullname\n";
+                mtrace("        $course->fullname");
                 //We check if the course exists in backup_course
                 $backup_course = get_record("backup_courses","courseid",$course->id);
                 //If it doesn't exist, create
@@ -74,25 +96,30 @@ function schedule_backup_cron() {
                 }
                 //If it doesn't exist now, error
                 if (!$backup_course) {
-                    echo "            ERROR (in backup_courses detection)\n";
+                    mtrace("            ERROR (in backup_courses detection)");
                     $status = false;
                 }
                 //Now we backup every course with nextstarttime < now
                 if ($backup_course->nextstarttime > 0 && $backup_course->nextstarttime < $now) {
-                    //Set laststarttime
-                    $starttime = time();
-                    set_field("backup_courses","laststarttime",$starttime,"courseid",$backup_course->courseid);
-                    //Launch backup
-                    $course_status = schedule_backup_launch_backup($course,$starttime);
                     //We have to send a email because we have included at least one backup
                     $emailpending = true;
-                    //Set lastendtime
-                    set_field("backup_courses","lastendtime",time(),"courseid",$backup_course->courseid);
-                    //Set laststatus
-                    if ($course_status) {
-                        set_field("backup_courses","laststatus","1","courseid",$backup_course->courseid);
-                    } else {
-                        set_field("backup_courses","laststatus","0","courseid",$backup_course->courseid);
+                    //Only make the backup if laststatus isn't 2-UNFINISHED (uncontrolled error)
+                    if ($backup_course->laststatus != 2) {
+                        //Set laststarttime
+                        $starttime = time();
+                        set_field("backup_courses","laststarttime",$starttime,"courseid",$backup_course->courseid);
+                        //Set course status to unfinished, the process will reset it
+                        set_field("backup_courses","laststatus","2","courseid",$backup_course->courseid);
+                        //Launch backup
+                        $course_status = schedule_backup_launch_backup($course,$starttime);
+                        //Set lastendtime
+                        set_field("backup_courses","lastendtime",time(),"courseid",$backup_course->courseid);
+                        //Set laststatus
+                        if ($course_status) {
+                            set_field("backup_courses","laststatus","1","courseid",$backup_course->courseid);
+                        } else {
+                            set_field("backup_courses","laststatus","0","courseid",$backup_course->courseid);
+                        }
                     }
                 }
 
@@ -105,37 +132,59 @@ function schedule_backup_cron() {
                 if ($nextstarttime > 0) {
                     $showtime = userdate($nextstarttime,"",$admin->timezone);
                 }
-                echo "            Next execution: $showtime\n";
+                mtrace("            Next execution: $showtime");
             }
         }
     }
 
     //Delete old logs
     if (!empty($CFG->loglifetime)) {
-        echo "    Deleting old logs\n";
+        mtrace("    Deleting old logs");
         $loglifetime = $now - ($CFG->loglifetime * 86400);
         delete_records_select("backup_log", "laststarttime < '$loglifetime'");
     }
 
-    //Send email to admin
+    //Send email to admin if necessary
     if ($emailpending) {
-        echo "    Sending email to admin\n";
+        mtrace("    Sending email to admin");
         $message = "";
-        //Build the message text (future versions should handle html messages too!!)
-        $logs = get_records_select ("backup_log","laststarttime >= '$now'","id");
-        if ($logs) {
-            $currentcourse = 1;
-            foreach ($logs as $log) {
-                if ($currentcourse != $log->courseid) {
-                    $message .= "\n==================================================\n\n";
-                    $currentcourse = $log->courseid;
-                }
-                $message .= userdate($log->time,"%T",$admin->timezone)." ".$log->info."\n";
-            }
+
+        //Get info about the status of courses
+        $count_all = count_records('backup_courses');
+        $count_ok = count_records('backup_courses','laststatus','1');
+        $count_error = count_records('backup_courses','laststatus','0');
+        $count_unfinished = count_records('backup_courses','laststatus','2');
+
+        //Build the message text
+        //Summary
+        $message .= get_string('summary')."\n";
+        $message .= "==================================================\n";
+        $message .= "  ".get_string('courses').": ".$count_all."\n";
+        $message .= "  ".get_string('ok').": ".$count_ok."\n";
+        $message .= "  ".get_string('error').": ".$count_error."\n";
+        $message .= "  ".get_string('unfinished').": ".$count_unfinished."\n\n";
+
+        //Reference
+        if ($count_error != 0 || $count_unfinished != 0) {
+            $message .= "  ".get_string('backupfailed')."\n\n";
+            $dest_url = $CFG->wwwroot.'/backup/log.php';
+            $message .= "  ".get_string('backuptakealook','',$dest_url)."\n\n";
+            //Reset unfinished to error
+            set_field('backup_courses','laststatus','0','laststatus','2');
+        } else {
+            $message .= "  ".get_string('backupfinished')."\n";
         }
-        //Send the message
+
+        //Build the message subject
         $site = get_site();
-        email_to_user($admin,$admin,"$site->shortname: ".get_string("scheduledbackupstatus"),$message);
+        $prefix = $site->shortname.": ";
+        if ($count_error != 0 || $count_unfinished != 0) {
+            $prefix .= "[".strtoupper(get_string('error'))."] ";
+        } 
+        $subject = $prefix.get_string("scheduledbackupstatus");
+
+        //Send the message
+        email_to_user($admin,$admin,$subject,$message);
     }
     
 
@@ -152,7 +201,7 @@ function schedule_backup_launch_backup($course,$starttime = 0) {
     $preferences = false;
     $status = false;
 
-    echo "            Executing backup\n";
+    mtrace("            Executing backup");
     schedule_backup_log($starttime,$course->id,"Start backup course $course->fullname");
     schedule_backup_log($starttime,$course->id,"  Phase 1: Checking and counting:");
     $preferences = schedule_backup_course_configure($course,$starttime);
@@ -161,6 +210,7 @@ function schedule_backup_launch_backup($course,$starttime = 0) {
         schedule_backup_log($starttime,$course->id,"  Phase 2: Executing and copying:");
         $status = schedule_backup_course_execute($preferences,$starttime);
     }
+
     if ($status && $preferences) {
         //Only if the backup_sche_keep is set
         if ($preferences->backup_keep) {
@@ -168,11 +218,12 @@ function schedule_backup_launch_backup($course,$starttime = 0) {
             $status = schedule_backup_course_delete_old_files($preferences,$starttime);
         }
     }
+
     if ($status && $preferences) {
-        echo "            End backup OK\n";
+        mtrace("            End backup OK");
         schedule_backup_log($starttime,$course->id,"End backup course $course->fullname - OK");
     } else {
-        echo "            End backup with ERROR\n";
+        mtrace("            End backup with ERROR");
         schedule_backup_log($starttime,$course->id,"End backup course $course->fullname - ERROR!!");
     }
 
@@ -187,7 +238,7 @@ function schedule_backup_log($starttime,$courseid,$message) {
         $log->courseid = $courseid;
         $log->time = time();
         $log->laststarttime = $starttime;
-        $log->info = $message;
+        $log->info = addslashes($message);
     
         insert_record ("backup_log",$log);
     }
@@ -374,11 +425,15 @@ function schedule_backup_course_configure($course,$starttime = 0) {
         $backup_name .= userdate(time(),$backup_date_format,99,false);
         //The extension
         $backup_name .= ".zip";
+        //And finally, clean everything
+        $backup_name = clean_filename($backup_name);
 
         //Calculate the string to match the keep preference
         $keep_name = $backup_word."-";
         //The shortname
         $keep_name .= strtolower($backup_shortname)."-";
+        //And finally, clean everything
+        $keep_name = clean_filename($keep_name);
  
         $preferences->backup_name = $backup_name;
         $preferences->keep_name = $keep_name;
@@ -479,17 +534,12 @@ function schedule_backup_course_execute($preferences,$starttime = 0) {
     //Create them as needed
     schedule_backup_log($starttime,$preferences->backup_course,"    checking temp structures");
     $status = check_and_create_backup_dir($preferences->backup_unique_code);
-    //Empty dir
+    //Empty backup dir
     if ($status) {
-        schedule_backup_log($starttime,$preferences->backup_course,"    cleaning old data");
+        schedule_backup_log($starttime,$preferences->backup_course,"    cleaning current dir");
         $status = clear_backup_dir($preferences->backup_unique_code);
     }
 
-    //Delete old_entries from backup tables
-    if ($status) {
-        $status = backup_delete_old_data();
-    }
-
     //Create the moodle.xml file
     if ($status) {
         schedule_backup_log($starttime,$preferences->backup_course,"    creating backup file");
@@ -649,7 +699,7 @@ function schedule_backup_course_delete_old_files($preferences,$starttime=0) {
         $dirtocheck = $CFG->dataroot."/".$preferences->backup_course."/backupdata";
     }
     schedule_backup_log($starttime,$preferences->backup_course,"    checking $dirtocheck");
-    echo "            Keeping backup files in $dirtocheck\n";
+    mtrace("            Keeping backup files in $dirtocheck");
 
     //Get all the files in $dirtocheck
     $files = get_directory_list($dirtocheck,"",false);
@@ -668,16 +718,16 @@ function schedule_backup_course_delete_old_files($preferences,$starttime=0) {
     //Count matching files
     $countmatching = count($matchingfiles);
     schedule_backup_log($starttime,$preferences->backup_course,"        found $countmatching backup files");
-    echo "                found $countmatching backup files\n";
+    mtrace("                found $countmatching backup files");
     if ($preferences->backup_keep < $countmatching) {
         schedule_backup_log($starttime,$preferences->backup_course,"        keep limit ($preferences->backup_keep) reached. Deleting old files");
-        echo "                keep limit ($preferences->backup_keep) reached. Deleting old files\n";
+        mtrace("                keep limit ($preferences->backup_keep) reached. Deleting old files");
         $filestodelete = $countmatching - $preferences->backup_keep;
         $filesdeleted = 0;
         foreach ($matchingfiles as $matchfile) {
             if ($filesdeleted < $filestodelete) {
                 schedule_backup_log($starttime,$preferences->backup_course,"        $matchfile deleted");
-                echo "                $matchfile deleted\n";
+                mtrace("                $matchfile deleted");
                 $filetodelete = $dirtocheck."/".$matchfile;
                 unlink($filetodelete);
                 $filesdeleted++;
