@@ -1,4 +1,4 @@
-<?PHP //$Id: backuplib.php,v 1.60 2004/05/20 18:36:59 stronk7 Exp $
+<?PHP //$Id: backuplib.php,v 1.65.2.9 2005/02/04 16:13:41 stronk7 Exp $
     //This file contains all the function needed in the backup utility
     //except the mod-related funtions that are into every backuplib.php inside
     //every mod directory
@@ -9,7 +9,7 @@
         $status = true;
         $status = execute_sql("INSERT INTO {$CFG->prefix}backup_ids
                                    (backup_code, table_name, old_id)
-                               SELECT DISTINCT '$backup_unique_code','quiz_categories',t.category
+                               SELECT DISTINCT $backup_unique_code,'quiz_categories',t.category
                                FROM {$CFG->prefix}quiz_questions t,
                                     {$CFG->prefix}quiz_question_grades g,
                                     {$CFG->prefix}quiz q
@@ -261,8 +261,9 @@
         $rootdir = $CFG->dataroot."/users";
         //Check if directory exists
         if (is_dir($rootdir)) {
-            $coursedirs = get_directory_list($rootdir);
-            foreach ($coursedirs as $dir) {
+            //Get directories without descend
+            $userdirs = get_directory_list($rootdir,"",false,true,false);
+            foreach ($userdirs as $dir) {
                 //Extracts user id from file path
                 $tok = strtok($dir,"/");
                 if ($tok) {
@@ -313,7 +314,8 @@
         $rootdir = $CFG->dataroot."/$course";
         //Check if directory exists
         if (is_dir($rootdir)) {
-            $coursedirs = get_directory_list($rootdir,$CFG->moddata);
+            //Get files and directories without descend
+            $coursedirs = get_directory_list($rootdir,$CFG->moddata,false,true,true);
             $backupdata_dir = "backupdata";
             foreach ($coursedirs as $dir) {
                 //Check it isn't backupdata_dir
@@ -464,6 +466,13 @@
         fwrite ($bf,full_tag("DATE",2,false,$preferences->backup_unique_code));
         //The original site wwwroot
         fwrite ($bf,full_tag("ORIGINAL_WWWROOT",2,false,$CFG->wwwroot));
+        //The zip method used
+        if (!empty($CFG->zip)) {
+            $zipmethod = 'external';
+        } else {
+            $zipmethod = 'internal';
+        }
+        fwrite ($bf,full_tag("ZIP_METHOD",2,false,$zipmethod));
         //Te includes tag
         fwrite ($bf,start_tag("DETAILS",2,true));
         //Now, go to mod element of preferences to print its status
@@ -534,18 +543,12 @@
         fwrite ($bf,start_tag("HEADER",2,true));
 
         //Get info from course
-        $course=false;
-        if ($courses = get_records("course","id",$preferences->backup_course)) {
-            $course = $courses[$preferences->backup_course];
-        }
+        $course = get_record("course","id",$preferences->backup_course);
         if ($course) {
             //Prints course info
             fwrite ($bf,full_tag("ID",3,false,$course->id));
             //Obtain the category
-            $category = false;
-            if ($categories = get_records("course_categories","id","$course->category")) {
-                $category = $categories[$course->category];
-            }
+            $category = get_record("course_categories","id","$course->category");
             if ($category) {
                 //Prints category info
                 fwrite ($bf,start_tag("CATEGORY",3,true));
@@ -557,6 +560,7 @@
             fwrite ($bf,full_tag("PASSWORD",3,false,$course->password));
             fwrite ($bf,full_tag("FULLNAME",3,false,$course->fullname));
             fwrite ($bf,full_tag("SHORTNAME",3,false,$course->shortname));
+            fwrite ($bf,full_tag("IDNUMBER",3,false,$course->idnumber));
             fwrite ($bf,full_tag("SUMMARY",3,false,$course->summary));
             fwrite ($bf,full_tag("FORMAT",3,false,$course->format));
             fwrite ($bf,full_tag("SHOWGRADES",3,false,$course->showgrades));
@@ -568,6 +572,7 @@
             fwrite ($bf,full_tag("STUDENTS",3,false,$course->students));
             fwrite ($bf,full_tag("GUEST",3,false,$course->guest));
             fwrite ($bf,full_tag("STARTDATE",3,false,$course->startdate));
+            fwrite ($bf,full_tag("ENROLPERIOD",3,false,$course->enrolperiod));
             fwrite ($bf,full_tag("NUMSECTIONS",3,false,$course->numsections));
             //fwrite ($bf,full_tag("SHOWRECENT",3,false,$course->showrecent));    INFO: This is out in 1.3
             fwrite ($bf,full_tag("MAXBYTES",3,false,$course->maxbytes));
@@ -575,6 +580,7 @@
             fwrite ($bf,full_tag("GROUPMODE",3,false,$course->groupmode));
             fwrite ($bf,full_tag("GROUPMODEFORCE",3,false,$course->groupmodeforce));
             fwrite ($bf,full_tag("LANG",3,false,$course->lang));
+            fwrite ($bf,full_tag("COST",3,false,$course->cost));
             fwrite ($bf,full_tag("MARKER",3,false,$course->marker));
             fwrite ($bf,full_tag("VISIBLE",3,false,$course->visible));
             fwrite ($bf,full_tag("HIDDENSECTIONS",3,false,$course->hiddensections));
@@ -717,6 +723,7 @@
                 fwrite ($bf,start_tag("USER",3,true));
                 //Output all user data
                 fwrite ($bf,full_tag("ID",4,false,$user_data->id));
+                fwrite ($bf,full_tag("AUTH",4,false,$user_data->auth));
                 fwrite ($bf,full_tag("CONFIRMED",4,false,$user_data->confirmed));
                 fwrite ($bf,full_tag("DELETED",4,false,$user_data->deleted));
                 fwrite ($bf,full_tag("USERNAME",4,false,$user_data->username));
@@ -746,6 +753,7 @@
                 fwrite ($bf,full_tag("URL",4,false,$user_data->url));
                 fwrite ($bf,full_tag("DESCRIPTION",4,false,$user_data->description));
                 fwrite ($bf,full_tag("MAILFORMAT",4,false,$user_data->mailformat));
+                fwrite ($bf,full_tag("MAILDIGEST",4,false,$user_data->maildigest));
                 fwrite ($bf,full_tag("MAILDISPLAY",4,false,$user_data->maildisplay));
                 fwrite ($bf,full_tag("HTMLEDITOR",4,false,$user_data->htmleditor));
                 fwrite ($bf,full_tag("AUTOSUBSCRIBE",4,false,$user_data->autosubscribe));
@@ -794,6 +802,8 @@
                         fwrite ($bf,full_tag("AUTHORITY",6,false,$tea->authority));
                         fwrite ($bf,full_tag("TEA_ROLE",6,false,$tea->role));
                         fwrite ($bf,full_tag("EDITALL",6,false,$tea->editall));
+                        fwrite ($bf,full_tag("TIMESTART",6,false,$tea->timestart));
+                        fwrite ($bf,full_tag("TIMEEND",6,false,$tea->timeend));
                         fwrite ($bf,full_tag("TIMEMODIFIED",6,false,$tea->timemodified));
                         fwrite ($bf,full_tag("TIMEACCESS",6,false,$tea->timeaccess));
                         //Print ROLE end
@@ -1056,8 +1066,10 @@
                 fwrite ($bf,full_tag("TIMECREATED",4,false,$group->timecreated));
                 fwrite ($bf,full_tag("TIMEMODIFIED",4,false,$group->timemodified));
                 
-                //Now, backup groups_members
-                $status2 = backup_groups_members_info($bf,$preferences,$group->id);
+                //Now, backup groups_members, only if users are included
+                if ($preferences->backup_users != 2) {
+                    $status2 = backup_groups_members_info($bf,$preferences,$group->id);
+                }
 
                 //End group tag
                 fwrite ($bf,end_tag("GROUP",3,true));
@@ -1134,8 +1146,9 @@
 
     //This function encode things to make backup multi-site fully functional
     //It does this conversions:
-    //    - $CFG->wwwroot/file.php/courseid ----------------------> $@FILEPHP@$
-    //    - Links to forums everywhere (DB) are encoded.
+    // - $CFG->wwwroot/file.php/courseid ------------------> $@FILEPHP@$ (slasharguments links)
+    // - $CFG->wwwroot/file.php?file=/courseid ------------> $@FILEPHP@$ (non-slasharguments links)
+    // - Every module xxxx_encode_content_links() is executed too
     //
     function backup_encode_absolute_links($content) {
 
@@ -1152,9 +1165,10 @@
         }
 
         //First, we check for every call to file.php inside the course
-        $search = array($CFG->wwwroot."/file.php/".$mypreferences->backup_course);
+        $search = array($CFG->wwwroot.'/file.php/'.$mypreferences->backup_course,
+                        $CFG->wwwroot.'/file.php?file=/'.$mypreferences->backup_course);
 
-        $replace = array("$@FILEPHP@$");
+        $replace = array('$@FILEPHP@$','$@FILEPHP@$');
 
         $result = str_replace($search,$replace,$content);
 
@@ -1257,48 +1271,20 @@
         $status = true;
 
         //Base dir where everything happens
-        $basedir = $CFG->dataroot."/temp/backup/".$preferences->backup_unique_code;
+        $basedir = cleardoubleslashes($CFG->dataroot."/temp/backup/".$preferences->backup_unique_code);
         //Backup zip file name
         $name = $preferences->backup_name;
-        //List base_dir files and directories
+        //List of files and directories
         $filelist = list_directories_and_files ($basedir);
 
-        if (empty($CFG->zip)) {    // Use built-in php-based zip function
-            //echo "<br>Using pclzip";                                    //Debug
-            $files = array();
-            foreach ($filelist as $file) {
-                //If directory, append "/"
-                //Commented. Not needed wit version 2.0 of pclzip !!
-                //if (is_dir($basedir."/".$file)) {
-                //    $file = $file."/";
-                //}
-                //Include into array
-                //echo "<br>Adding file/dir ".$file;                       //Debug
-                $files[] = $basedir."/".$file;
-            }
-            include_once("$CFG->dirroot/lib/pclzip/pclzip.lib.php");
-            //include_once("$CFG->dirroot/lib/pclzip/pclerror.lib.php");   //Debug
-            //include_once("$CFG->dirroot/lib/pclzip/pcltrace.lib.php");   //Debug
-            //PclTraceOn(2);                                               //Debug
-            $archive = new PclZip("$basedir/$name");
-            if (($list = $archive->create($files,PCLZIP_OPT_REMOVE_PATH,$basedir)) == 0) {
-                error($archive->errorInfo(true));
-                $status = false;
-            } 
-            //PclTraceDisplay();                                           //Debug
-            //PclTraceOff();                                               //Debug
-        } else {                   // Use external zip program
-            //echo "<br>Using external zip";                               //Debug
-            $files = "";
-            foreach ($filelist as $file) {
-                $files .= basename($file);
-                $files .= " ";
-            }
-            $command = "cd $basedir ; $CFG->zip -r $name $files";
-            //echo "<br>Executing command: ".$command;                     //Debug
-            $status = Exec($command);
+        //Convert them to full paths
+        $files = array();
+        foreach ($filelist as $file) {
+           $files[] = "$basedir/$file";
         }
 
+        $status = zip_files($files, "$basedir/$name");
+
         //echo "<br>Status: ".$status;                                     //Debug
         return $status;
 
