@@ -1,4 +1,4 @@
-<?PHP //$Id: lib.php,v 1.50 2004/04/18 23:20:27 stronk7 Exp $
+<?PHP //$Id: lib.php,v 1.51.4.1 2004/09/24 11:47:03 stronk7 Exp $
     //This file contains all the general function needed (file manipulation...)
     //not directly part of the backup/restore utility
 
@@ -25,15 +25,15 @@
     }
 
     //Delete old data in backup tables (if exists)
-    //Two days seems to be apropiate
+    //Four hours seem to be appropiate now that backup is stable
     function backup_delete_old_data() {
 
         global $CFG; 
 
         //Change this if you want !!
-        $days = 2;
+        $hours = 4;
         //End change this
-        $seconds = $days * 24 * 60 * 60;
+        $seconds = $hours * 60 * 60;
         $delete_from = time()-$seconds;
         //Now delete from tables
         $status = execute_sql("DELETE FROM {$CFG->prefix}backup_ids
@@ -56,7 +56,8 @@
         global $CFG;
 
         $status = true;
-        $list = get_directory_list($CFG->dataroot."/temp/backup", "", false);
+        //Get files and directories in the temp backup dir witout descend
+        $list = get_directory_list($CFG->dataroot."/temp/backup", "", false, true, true);
         foreach ($list as $file) {
             $file_path = $CFG->dataroot."/temp/backup/".$file;
             $moddate = filemtime($file_path);
