@@ -1,4 +1,4 @@
-<?PHP //$Id: block_activity_modules.php,v 1.1 2004/04/18 23:20:28 stronk7 Exp $
+<?PHP //$Id: block_activity_modules.php,v 1.2 2004/07/28 11:58:48 moodler Exp $
 
 class CourseBlock_activity_modules extends MoodleBlock {
     function CourseBlock_activity_modules($course) {
@@ -26,7 +26,7 @@ class CourseBlock_activity_modules extends MoodleBlock {
         if ($modnamesused) {
             foreach ($modnamesused as $modname => $modfullname) {
                 if ($modname != 'label') {
-                    $this->content->items[] = '<a href="../mod/'.$modname.'/index.php?id='.$this->course->id.'">'.$modnamesplural[$modname].'</a>';
+                    $this->content->items[] = '<a href="'.$CFG->wwwroot.'/mod/'.$modname.'/index.php?id='.$this->course->id.'">'.$modnamesplural[$modname].'</a>';
                     $this->content->icons[] = '<img src="'.$CFG->modpixpath.'/'.$modname.'/icon.gif" height="16" width="16" alt="">';
                 }
             }
