@@ -1,4 +1,4 @@
-<?php // $Id: lib.php,v 1.61 2004/05/26 11:03:27 defacer Exp $
+<?php // $Id: lib.php,v 1.74.2.11 2005/02/22 10:33:11 moodler Exp $
 
 /////////////////////////////////////////////////////////////////////////////
 //                                                                         //
@@ -47,7 +47,7 @@ else {
 }
 
 define ('SECS_IN_DAY', 86400);
-define ('CALENDAR_UPCOMING_DAYS', 14);
+define ('CALENDAR_UPCOMING_DAYS', 21);
 define ('CALENDAR_UPCOMING_MAXEVENTS', 10);
 define ('CALENDAR_URL', $CFG->wwwroot.'/calendar/');
 define ('CALENDAR_TF_24', '%H:%M');
@@ -112,17 +112,17 @@ function calendar_get_mini($courses, $groups, $users, $cal_month = false, $cal_y
         $events = array();
     }
     else {
-        $events = get_records_select('event', $whereclause);
+        $events = get_records_select('event', $whereclause, 'timestart');
     }
 
     // This is either a genius idea or an idiot idea: in order to not complicate things, we use this rule: if, after
-    // possibly removing courseid 1 from $courses, there is only one course left, then clicking on a day in the month
+    // possibly removing SITEID from $courses, there is only one course left, then clicking on a day in the month
     // will also set the $SESSION->cal_courses_shown variable to that one course. Otherwise, we 'd need to add extra
     // arguments to this function.
 
     $morehref = '';
     if(!empty($courses)) {
-        $courses = array_diff($courses, array(1));
+        $courses = array_diff($courses, array(SITEID));
         if(count($courses) == 1) {
             $morehref = '&amp;course='.reset($courses);
         }
@@ -130,7 +130,8 @@ function calendar_get_mini($courses, $groups, $users, $cal_month = false, $cal_y
 
     // We want to have easy access by day, since the display is on a per-day basis.
     // Arguments passed by reference.
-    calendar_events_by_day($events, $display->tstart, $eventsbyday, $durationbyday, $typesbyday);
+    //calendar_events_by_day($events, $display->tstart, $eventsbyday, $durationbyday, $typesbyday);
+    calendar_events_by_day($events, $m, $y, $eventsbyday, $durationbyday, $typesbyday);
 
     $content .= '<table class="calendarmini">'; // Begin table
     $content .= '<thead><tr>'; // Header row: day names
@@ -189,12 +190,12 @@ function calendar_get_mini($courses, $groups, $users, $cal_month = false, $cal_y
                     $popupicon = $CFG->modpixpath.'/'.$event->modulename.'/icon.gif';
                     $popupalt  = $event->modulename;
 
-                } else if ($event->courseid == 1) {                                // Site event
+                } else if ($event->courseid == SITEID) {                                // Site event
                     $popupicon = $CFG->pixpath.'/c/site.gif';
                     $popupalt  = '';
-                } else if ($event->courseid > 1 and empty($event->groupid)) {      // Course event
+                } else if ($event->courseid != 0 && $event->courseid != SITEID && $event->groupid == 0) {      // Course event
                     $popupicon = $CFG->pixpath.'/c/course.gif';
-                   $popupalt  = '';
+                    $popupalt  = '';
                 } else if ($event->groupid) {                                      // Group event
                     $popupicon = $CFG->pixpath.'/c/group.gif';
                     $popupalt  = '';
@@ -202,10 +203,11 @@ function calendar_get_mini($courses, $groups, $users, $cal_month = false, $cal_y
                     $popupicon = $CFG->pixpath.'/c/user.gif';
                     $popupalt  = '';
                 }
-                $popupcontent .= '<div><img height=16 width=16 src=\\\''.$popupicon.'\\\' style=\\\'vertical-align: middle; margin-right: 4px;\\\' alt=\\\''.$popupalt.'\\\' /><a href=\\\''.$dayhref.'\\\'>'.addslashes(htmlspecialchars($event->name)).'</a></div>';
+                $popupcontent .= '<div><img height="16" width="16" src="'.$popupicon.'" style="vertical-align: middle; margin-right: 4px;" alt="'.$popupalt.'" /><a href="'.$dayhref.'">'.$event->name.'</a></div>';
             }
 
             $popupcaption = get_string('eventsfor', 'calendar', userdate($events[$eventid]->timestart, $strftimetimedayshort));
+            $popupcontent = str_replace("'", "\'", htmlspecialchars($popupcontent));
             $popup = 'onmouseover="return overlib(\''.$popupcontent.'\', CAPTION, \''.$popupcaption.'\');" onmouseout="return nd();"';
 
             // Class and cell content
@@ -277,18 +279,20 @@ function calendar_get_upcoming($courses, $groups, $users, $daysinfuture, $maxeve
 
     $processed = 0;
     $now = time(); // We 'll need this later
-    $nowsecs = $now % SECS_IN_DAY; // this too
-    $nowdays = $now - $nowsecs; // and this
+    $usermidnighttoday = usergetmidnight($now);
 
     if ($fromtime) {
         $display->tstart = $fromtime;
     } else {
-        $display->tstart = usergetmidnight(time());
+        $display->tstart = $usermidnighttoday;
     }
 
     // This effectively adds as many days as needed, and the final SECS_IN_DAY - 1
     // serves to cover the duration until the end of the final day. We could
     // just do another gmmktime() and an addition, but this is "faster" :)
+
+    // WARNING: IT IS ALSO BUGGY WITH REGARDS TO DST CHANGES! THIS HAS TO BE FIXED SOMEDAY!
+    // IF YOU DO SECS ARITHMETIC, THE CODE WILL ALWAYS BE BUGGY WITH REGARD TO DST!
     $display->tend = $display->tstart + (SECS_IN_DAY * $display->range) - 1;
 
     // Get the events matching our criteria
@@ -296,18 +300,17 @@ function calendar_get_upcoming($courses, $groups, $users, $daysinfuture, $maxeve
     if ($whereclause === false) {
         $events = false;
     } else {
-        $whereclause .= ' ORDER BY timestart'; // We want them this way
-        $events = get_records_select('event', $whereclause);
+        $events = get_records_select('event', $whereclause, 'timestart');
     }
 
     // This is either a genius idea or an idiot idea: in order to not complicate things, we use this rule: if, after
-    // possibly removing courseid 1 from $courses, there is only one course left, then clicking on a day in the month
+    // possibly removing SITEID from $courses, there is only one course left, then clicking on a day in the month
     // will also set the $SESSION->cal_courses_shown variable to that one course. Otherwise, we 'd need to add extra
     // arguments to this function.
 
     $morehref = '';
     if(!empty($courses)) {
-        $courses = array_diff($courses, array(1));
+        $courses = array_diff($courses, array(SITEID));
         if(count($courses) == 1) {
             $morehref = '&amp;course='.reset($courses);
         }
@@ -315,70 +318,12 @@ function calendar_get_upcoming($courses, $groups, $users, $daysinfuture, $maxeve
 
     if($events !== false) {
         foreach($events as $event) {
-            if($processed >= $display->maxevents) break;
 
-            $startdate = usergetdate($event->timestart);
-            $enddate = usergetdate($event->timestart + $event->timeduration);
-
-            $starttimesecs = $event->timestart % SECS_IN_DAY; // Seconds after that day's midnight
-            $starttimedays = $event->timestart - $starttimesecs; // Timestamp of midnight of that day
-
-            if($event->timeduration) {
-                // To avoid doing the math if one IF is enough :)
-                $endtimesecs = ($event->timestart + $event->timeduration) % SECS_IN_DAY; // Seconds after that day's midnight
-                $endtimedays = ($event->timestart + $event->timeduration) - $endtimesecs; // Timestamp of midnight of that day
-            }
-            else {
-                $endtimesecs = $starttimesecs;
-                $endtimedays = $starttimedays;
+            if($processed >= $display->maxevents) {
+                break;
             }
 
-            // Keep in mind: $starttimeXXX, $endtimeXXX and $nowXXX are all in GMT-based
-            // OK, now to get a meaningful display...
-
-            // First of all we have to construct a human-readable date/time representation
-            if($endtimedays < $nowdays || $endtimedays == $nowdays && $endtimesecs <= $nowsecs) {
-                // It has expired, so we don't care about duration
-                $day = calendar_day_representation($event->timestart + $event->timeduration, $now);
-                $time = calendar_time_representation($event->timestart + $event->timeduration);
-
-                // This var always has the printable time representation
-                $eventtime = '<span class="dimmed_text"><a class="dimmed" href="'.calendar_get_link_href(CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $enddate['mday'], $enddate['mon'], $enddate['year']).'">'.$day.'</a> ('.$time.')</span>';
-
-            }
-            else if($event->timeduration) {
-                // It has a duration
-                if($starttimedays == $endtimedays) {
-                    // But it's all on one day
-                    $day = calendar_day_representation($event->timestart, $now);
-                    $timestart = calendar_time_representation($event->timestart);
-                    $timeend = calendar_time_representation($event->timestart + $event->timeduration);
-
-                    // Set printable representation
-                    $eventtime = calendar_get_link_tag($day, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $enddate['mday'], $enddate['mon'], $enddate['year']).
-                        ' ('.$timestart.' -> '.$timeend.')';
-                }
-                else {
-                    // It spans two or more days
-                    $daystart = calendar_day_representation($event->timestart, $now);
-                    $dayend = calendar_day_representation($event->timestart + $event->timeduration, $now);
-                    $timestart = calendar_time_representation($event->timestart);
-                    $timeend = calendar_time_representation($event->timestart + $event->timeduration);
-
-                    // Set printable representation
-                    $eventtime = calendar_get_link_tag($daystart, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $startdate['mday'], $startdate['mon'], $startdate['year']).
-                        ' ('.$timestart.') -> '.calendar_get_link_tag($dayend, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $enddate['mday'], $enddate['mon'], $enddate['year']).
-                        ' ('.$timeend.')';
-                }
-            }
-            else {
-                // It's an "instantaneous" event
-                $day = calendar_day_representation($event->timestart, $now);
-                $time = calendar_time_representation($event->timestart);
-
-                // Set printable representation
-                $eventtime = calendar_get_link_tag($day, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $startdate['mday'], $startdate['mon'], $startdate['year']).' ('.$time.')';
-            }
+            $eventtime = calendar_format_event_time($event, $now, $morehref);
 
             $outkey = count($output);
 
@@ -412,14 +357,12 @@ function calendar_get_upcoming($courses, $groups, $users, $daysinfuture, $maxeve
                 $output[$outkey]->cmid = $module->id;
 
 
-
-            } else if($event->courseid == 1) {                              // Site event
+            } else if($event->courseid == SITEID) {                              // Site event
                 $output[$outkey]->icon = '<img height=16 width=16 src="'.$CFG->pixpath.'/c/site.gif" alt="" style="vertical-align: middle;" />';
                 $output[$outkey]->time = $eventtime;
 
 
-
-            } else if($event->courseid > 1 and !$event->groupid) {          // Course event
+            } else if($event->courseid != 0 && $event->courseid != SITEID && $event->groupid == 0) {          // Course event
                 calendar_get_course_cached($coursecache, $event->courseid);
 
                 $output[$outkey]->icon = '<img height=16 width=16 src="'.$CFG->pixpath.'/c/course.gif" alt="" style="vertical-align: middle;" />';
@@ -466,6 +409,11 @@ function calendar_sql_where($tstart, $tend, $users, $groups, $courses, $withdura
         if(!empty($whereclause)) $whereclause .= ' OR';
         $whereclause .= ' userid != 0 AND courseid = 0 AND groupid = 0';
     }
+    else if($users === false) {
+        // No user at all
+        // No need to do anything
+    }
+
     if(is_array($groups) && !empty($groups)) {
         // Events from a number of groups
         if(!empty($whereclause)) $whereclause .= ' OR';
@@ -481,10 +429,20 @@ function calendar_sql_where($tstart, $tend, $users, $groups, $courses, $withdura
         if(!empty($whereclause)) $whereclause .= ' OR ';
         $whereclause .= ' groupid != 0';
     }
-    if(is_array($courses) && !empty($courses)) {
-        // A number of courses
-        if(!empty($whereclause)) $whereclause .= ' OR';
-        $whereclause .= ' groupid = 0 AND courseid IN ('.implode(',', $courses).')';
+    // boolean false (no groups at all): we don't need to do anything
+
+    if(is_array($courses)) {
+        // A number of courses (maybe none at all!)
+        if(!empty($courses)) {
+            if(!empty($whereclause)) {
+                $whereclause .= ' OR';
+            }
+            $whereclause .= ' groupid = 0 AND courseid IN ('.implode(',', $courses).')';
+        }
+        else {
+            // This means NO courses, not that we don't care!
+            // No need to do anything
+        }
     }
     else if(is_numeric($courses)) {
         // One course
@@ -497,6 +455,14 @@ function calendar_sql_where($tstart, $tend, $users, $groups, $courses, $withdura
         $whereclause .= ' groupid = 0 AND courseid != 0';
     }
 
+    // Security check: if, by now, we have NOTHING in $whereclause, then it means
+    // that NO event-selecting clauses were defined. Thus, we won't be returning ANY
+    // events no matter what. Allowing the code to proceed might return a completely
+    // valid query with only time constraints, thus selecting ALL events in that time frame!
+    if(empty($whereclause)) {
+        return false;
+    }
+
     if ($ignorehidden) {
         if (!empty($whereclause)) $whereclause .= ' AND';
         $whereclause .= ' visible = 1';
@@ -516,7 +482,8 @@ function calendar_sql_where($tstart, $tend, $users, $groups, $courses, $withdura
         // Just basic time filtering
         $whereclause = $timeclause;
     }
-    return $whereclause;
+
+    return empty($whereclause) ? false : $whereclause;
 }
 
 function calendar_top_controls($type, $data) {
@@ -573,8 +540,8 @@ function calendar_top_controls($type, $data) {
         case 'day':
             $data['d'] = $date['mday']; // Just for convenience
             $dayname = calendar_wday_name($date['weekday']);
-            $prevdate = getdate($time - SECS_IN_DAY);
-            $nextdate = getdate($time + SECS_IN_DAY);
+            $prevdate = getdate(make_timestamp($data['y'], $data['m'], $data['d'] - 1));
+            $nextdate = getdate(make_timestamp($data['y'], $data['m'], $data['d'] + 1));
             $prevname = calendar_wday_name($prevdate['weekday']);
             $nextname = calendar_wday_name($nextdate['weekday']);
             $content .= "<table style='width: 100%;'><tr>\n";
@@ -611,7 +578,11 @@ function calendar_filter_controls($type, $vars = NULL, $course = NULL) {
             $getvars = '&amp;from='.$type;
         break;
         case 'course':
-            $getvars = '&amp;from=course&amp;id='.$_GET['id'];
+            if (isset($_GET['id'])) {
+                $getvars = '&amp;from=course&amp;id='.$_GET['id'];
+            } else {
+                $getvars = '&amp;from=course';
+            }
             if (isset($course->groupmode) and !$course->groupmode and $course->groupmodeforce) {
                 $groupevents = false;
             }
@@ -638,7 +609,7 @@ function calendar_filter_controls($type, $vars = NULL, $course = NULL) {
         $content .= '<td style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showcourses'.$getvars.'" title="'.get_string('tt_showcourse', 'calendar').'">'.get_string('courseevents', 'calendar').'</a></td>'."\n";
     }
 
-    if(!isguest($USER->id)) {
+    if(!empty($USER->id) && !isguest()) {
         $content .= "</tr>\n<tr>";
 
         if($groupevents) {
@@ -684,27 +655,28 @@ function calendar_day_representation($tstamp, $now = false, $usecommonwords = tr
     // To have it in one place, if a change is needed
     $formal = userdate($tstamp, $shortformat);
 
-    // Reverse TZ compensation: make GMT stamps correspond to user's TZ
-    $tzfix = calendar_get_tz_offset();
-    $tstamp += $tzfix;
-    $now += $tzfix;
-
-    $eventdays = intval($tstamp / SECS_IN_DAY);
-    $nowdays = intval($now / SECS_IN_DAY);
+    $datestamp = usergetdate($tstamp);
+    $datenow   = usergetdate($now);
 
     if($usecommonwords == false) {
         // We don't want words, just a date
         return $formal;
     }
-    else if($eventdays == $nowdays) {
+    else if($datestamp['year'] == $datenow['year'] && $datestamp['yday'] == $datenow['yday']) {
         // Today
         return get_string('today', 'calendar');
     }
-    else if($eventdays == $nowdays - 1) {
+    else if(
+        ($datestamp['year'] == $datenow['year'] && $datestamp['yday'] == $datenow['yday'] - 1 ) ||
+        ($datestamp['year'] == $datenow['year'] - 1 && $datestamp['mday'] == 31 && $datestamp['mon'] == 12 && $datenow['yday'] == 1)
+        ) {
         // Yesterday
         return get_string('yesterday', 'calendar');
     }
-    else if($eventdays == $nowdays + 1) {
+    else if(
+        ($datestamp['year'] == $datenow['year'] && $datestamp['yday'] == $datenow['yday'] + 1 ) ||
+        ($datestamp['year'] == $datenow['year'] + 1 && $datenow['mday'] == 31 && $datenow['mon'] == 12 && $datestamp['yday'] == 1)
+        ) {
         // Tomorrow
         return get_string('tomorrow', 'calendar');
     }
@@ -759,28 +731,15 @@ function calendar_mktime_check($m, $d, $y, $default = false) {
     }
 }
 
-function calendar_month_name($month) {
-    if(is_int($month)) {
-        // 1 ... 12 integer converted to month name
-        $months = array('january', 'february', 'march', 'april', 'may', 'june', 'july', 'august', 'september', 'october', 'november', 'december');
-        return get_string($months[$month - 1], 'calendar');
-    }
-    else {
-        return get_string(strtolower($month), 'calendar');
-    }
-}
-
 function calendar_wday_name($englishname) {
     return get_string(strtolower($englishname), 'calendar');
 }
 
 function calendar_days_in_month($month, $year) {
-   return date('t', mktime(0, 0, 0, $month, 1, $year));
+   return intval(date('t', mktime(0, 0, 0, $month, 1, $year)));
 }
 
-function calendar_get_sideblock_upcoming($courses, $groups, $users, $daysinfuture, $maxevents) {
-    $events = calendar_get_upcoming($courses, $groups, $users, $daysinfuture, $maxevents);
-
+function calendar_get_sideblock_upcoming($events, $linkhref = NULL) {
     $content = '';
     $lines = count($events);
     if (!$lines) {
@@ -788,12 +747,22 @@ function calendar_get_sideblock_upcoming($courses, $groups, $users, $daysinfutur
     }
 
     for ($i = 0; $i < $lines; ++$i) {
+        if (!isset($events[$i]->time)) {   // Just for robustness
+            continue;
+        }
         $content .= '<div class="cal_event">'.$events[$i]->icon.' ';
         if (!empty($events[$i]->referer)) {
             // That's an activity event, so let's provide the hyperlink
             $content .= $events[$i]->referer;
         } else {
-            $content .= $events[$i]->name;
+            if(!empty($linkhref)) {
+                $ed = usergetdate($events[$i]->timestart);
+                $href = calendar_get_link_href(CALENDAR_URL.$linkhref, $ed['mday'], $ed['mon'], $ed['year']);
+                $content .= '<a href="'.$href.'">'.$events[$i]->name.'</a>';
+            }
+            else {
+                $content .= $events[$i]->name;
+            }
         }
         $events[$i]->time = str_replace('->', '<br />->', $events[$i]->time);
         $content .= '</div><div class="cal_event_date" style="text-align:right;">'.$events[$i]->time.'</div>';
@@ -821,7 +790,7 @@ function calendar_sub_month($month, $year) {
     }
 }
 
-function calendar_events_by_day($events, $starttime, &$eventsbyday, &$durationbyday, &$typesbyday) {
+function calendar_events_by_day($events, $month, $year, &$eventsbyday, &$durationbyday, &$typesbyday) {
     $eventsbyday = array();
     $typesbyday = array();
     $durationbyday = array();
@@ -830,61 +799,66 @@ function calendar_events_by_day($events, $starttime, &$eventsbyday, &$durationby
         return;
     }
 
-    // Reverse TZ compensation: make GMT stamps (from event table) correspond to user's TZ
-    $tzfix = calendar_get_tz_offset();
-
     foreach($events as $event) {
-        $eventdaystart = 1 + floor(($event->timestart + $tzfix - $starttime) / SECS_IN_DAY);
-        $eventdayend = 1 + floor(($event->timestart + $event->timeduration + $tzfix - $starttime) / SECS_IN_DAY);
 
-        // Give the event to its day
-        $eventsbyday[$eventdaystart][] = $event->id;
+        $startdate = usergetdate($event->timestart);
+        $enddate   = usergetdate($event->timestart + $event->timeduration);
 
-        // Mark the day as having such an event
-        if($event->courseid == 1 && $event->groupid == 0) {
-            $typesbyday[$eventdaystart]['startglobal'] = true;
-        }
-        else if($event->courseid > 1 && $event->groupid == 0) {
-            $typesbyday[$eventdaystart]['startcourse'] = true;
-        }
-        else if($event->groupid) {
-            $typesbyday[$eventdaystart]['startgroup'] = true;
-        }
-        else if($event->userid) {
-            $typesbyday[$eventdaystart]['startuser'] = true;
+        // Simple arithmetic: $year * 13 + $month is a distinct integer for each distinct ($year, $month) pair
+        if(!($startdate['year'] * 13 + $startdate['mon'] <= $year * 13 + $month) && ($enddate['year'] * 13 + $enddate['mon'] >= $year * 13 + $month)) {
+            // Out of bounds
+            continue;
         }
 
-        // Mark all days up to and including ending day as duration
-        if($eventdaystart < $eventdayend) {
+        $eventdaystart = intval($startdate['mday']);
 
-            // Normally this should be
+        if($startdate['mon'] == $month && $startdate['year'] == $year) {
+            // Give the event to its day
+            $eventsbyday[$eventdaystart][] = $event->id;
 
-            // $bound = min($eventdayend, $display->maxdays);
-            // for($i = $eventdaystart + 1; $i <= $bound; ++$i) {
-
-            // So that we don't go on marking days after the end of
-            // the month if the event continues. However, this code
-            // has moved and now we don't have access to $display->maxdays.
-            // In order to save the overhead of recomputing it, we just
-            // use this "dumb" approach. Anyway, the function that called
-            // us already knows up to what day it should display.
-
-            for($i = $eventdaystart + 1; $i <= $eventdayend; ++$i) {
-                $durationbyday[$i][] = $event->id;
-                if($event->courseid == 1 && $event->groupid == 0) {
-                    $typesbyday[$i]['durationglobal'] = true;
-                }
-                else if($event->courseid > 1 && $event->groupid == 0) {
-                    $typesbyday[$i]['durationcourse'] = true;
-                }
-                else if($event->groupid) {
-                    $typesbyday[$i]['durationgroup'] = true;
-                }
-                else if($event->userid) {
-                    $typesbyday[$i]['durationuser'] = true;
-                }
+            // Mark the day as having such an event
+            if($event->courseid == SITEID && $event->groupid == 0) {
+                $typesbyday[$eventdaystart]['startglobal'] = true;
+            }
+            else if($event->courseid != 0 && $event->courseid != SITEID && $event->groupid == 0) {
+                $typesbyday[$eventdaystart]['startcourse'] = true;
+            }
+            else if($event->groupid) {
+                $typesbyday[$eventdaystart]['startgroup'] = true;
+            }
+            else if($event->userid) {
+                $typesbyday[$eventdaystart]['startuser'] = true;
             }
         }
+
+        if($event->timeduration == 0) {
+            // Proceed with the next
+            continue;
+        }
+
+        // The event starts on $month $year or before. So...
+        $lowerbound = $startdate['mon'] == $month && $startdate['year'] == $year ? intval($startdate['mday']) : 0;
+
+        // Also, it ends on $month $year or later...
+        $upperbound = $enddate['mon'] == $month && $enddate['year'] == $year ? intval($enddate['mday']) : calendar_days_in_month($month, $year);
+
+        // Mark all days between $lowerbound and $upperbound (inclusive) as duration
+        for($i = $lowerbound + 1; $i <= $upperbound; ++$i) {
+            $durationbyday[$i][] = $event->id;
+            if($event->courseid == SITEID && $event->groupid == 0) {
+                $typesbyday[$i]['durationglobal'] = true;
+            }
+            else if($event->courseid != 0 && $event->courseid != SITEID && $event->groupid == 0) {
+                $typesbyday[$i]['durationcourse'] = true;
+            }
+            else if($event->groupid) {
+                $typesbyday[$i]['durationgroup'] = true;
+            }
+            else if($event->userid) {
+                $typesbyday[$i]['durationuser'] = true;
+            }
+        }
+
     }
     return;
 }
@@ -909,6 +883,19 @@ function calendar_get_course_cached(&$coursecache, $courseid) {
 function calendar_session_vars() {
     global $SESSION, $USER;
 
+    if(!empty($USER->id) && isset($USER->realuser) && !isset($SESSION->cal_loggedinas)) {
+        // We just logged in as someone else, update the filtering
+        unset($SESSION->cal_users_shown);
+        unset($SESSION->cal_courses_shown);
+        $SESSION->cal_loggedinas = true;
+    }
+    else if(!empty($USER->id) && !isset($USER->realuser) && isset($SESSION->cal_loggedinas)) {
+        // We just logged back to our real self, update again
+        unset($SESSION->cal_users_shown);
+        unset($SESSION->cal_courses_shown);
+        unset($SESSION->cal_loggedinas);
+    }
+
     if(!isset($SESSION->cal_course_referer)) {
         $SESSION->cal_course_referer = 0;
     }
@@ -922,11 +909,21 @@ function calendar_session_vars() {
         $SESSION->cal_show_course = true;
     }
     if(!isset($SESSION->cal_show_user)) {
-        $SESSION->cal_show_user = isset($USER->id) ? $USER->id : false;
+        $SESSION->cal_show_user = true;
     }
     if(empty($SESSION->cal_courses_shown)) {
         $SESSION->cal_courses_shown = calendar_get_default_courses(true);
     }
+    if(empty($SESSION->cal_users_shown)) {
+        // The empty() instead of !isset() here makes a whole world of difference,
+        // as it will automatically change to the user's id when the user first logs
+        // in. With !isset(), it would never do that.
+        $SESSION->cal_users_shown = isset($USER->id) ? $USER->id : false;
+    }
+    else if(is_numeric($SESSION->cal_users_shown) && !empty($USER->id) && $SESSION->cal_users_shown != $USER->id) {
+        // Follow the white rabbit, for example if a teacher logs in as a student
+        $SESSION->cal_users_shown = $USER->id;
+    }
 }
 
 function calendar_overlib_html() {
@@ -963,11 +960,11 @@ function calendar_set_filters(&$courses, &$group, &$user, $courseeventsfrom = NU
 
     if(($SESSION->cal_show_course && $SESSION->cal_show_global) || $ignorefilters) {
         if(is_int($courseeventsfrom)) {
-            $courses = array(1, $courseeventsfrom);
+            $courses = array(SITEID, $courseeventsfrom);
         }
         else if(is_array($courseeventsfrom)) {
             $courses = array_keys($courseeventsfrom);
-            $courses[] = 1;
+            $courses[] = SITEID;
         }
     }
     else if($SESSION->cal_show_course) {
@@ -977,22 +974,18 @@ function calendar_set_filters(&$courses, &$group, &$user, $courseeventsfrom = NU
         else if(is_array($courseeventsfrom)) {
             $courses = array_keys($courseeventsfrom);
         }
-        $courses = array_diff($courses, array(1));
+        $courses = array_diff($courses, array(SITEID));
     }
     else if($SESSION->cal_show_global) {
-        $courses = array(1);
+        $courses = array(SITEID);
     }
     else {
         $courses = false;
     }
 
     if($SESSION->cal_show_user || $ignorefilters) {
-        // This ignores the "which user to see" setting
-        // The functionality to do that does exist, but this was
-        // the most painless way to solve bug 1323. And anyway,
-        // it wasn't being used anywhere.
-        $user = $USER->id;
-        //$user = $SESSION->cal_show_user;
+        // This doesn't work for arrays yet (maybe someday it will)
+        $user = $SESSION->cal_users_shown;
     }
     else {
         $user = false;
@@ -1010,7 +1003,7 @@ function calendar_set_filters(&$courses, &$group, &$user, $courseeventsfrom = NU
         // For each course...
         foreach($groupcourses as $courseid) {
             // If the user is an editing teacher in there,
-            if(isteacheredit($courseid, $USER->id)) {
+            if(!empty($USER->id) && isteacheredit($courseid, $USER->id)) {
                 // Show events from all groups
                 if(($grouprecords = get_groups($courseid)) !== false) {
                     $grouparray = array_merge($grouparray, array_keys($grouprecords));
@@ -1036,9 +1029,13 @@ function calendar_set_filters(&$courses, &$group, &$user, $courseeventsfrom = NU
 function calendar_edit_event_allowed($event) {
     global $USER;
 
+    if(empty($USER->id) || isguest($USER->id)) {
+        return false;
+    }
+
     if (isadmin($USER->id)) return true; // Admins are allowed anything
 
-    if ($event->courseid > 1) {
+    if ($event->courseid != 0 && $event->courseid != SITEID) {
         // Course event, only editing teachers may... edit :P
         if(isteacheredit($event->courseid)) {
             return true;
@@ -1064,15 +1061,15 @@ function calendar_get_default_courses($ignoreref = false) {
     global $USER, $CFG, $SESSION;
 
     if(!empty($SESSION->cal_course_referer) && !$ignoreref) {
-        return array($SESSION->cal_course_referer => 1);
+        return array($SESSION->cal_course_referer => SITEID);
     }
 
-    if(empty($USER)) {
+    if(empty($USER->id)) {
         return array();
     }
 
     $courses = array();
-    if(isadmin($USER->id)) {
+    if(!empty($USER->id) && isadmin($USER->id)) {
         $courses = get_records_sql('SELECT id, 1 FROM '.$CFG->prefix.'course');
         return $courses;
     }
@@ -1085,40 +1082,6 @@ function calendar_get_default_courses($ignoreref = false) {
     return $courses;
 }
 
-function calendar_get_tz_offset() {
-    global $USER, $CFG;
-    static $tzfix;
-
-    // Caching
-    if(isset($tzfix)) {
-        return $tzfix;
-    }
-
-    if(empty($USER)) {
-        // Don't forget that there are users which have NOT logged in, even as guests
-        $timezone = $CFG->timezone;
-    }
-    else {
-        // If, on the other hand, we do have a user...
-        $timezone = $USER->timezone;
-        if(abs($timezone > 13)) {
-            // But if the user has specified 'server default' time,
-            // don't get the server's; get the Moodle $CFG setting
-            // (Martin's help text on site cfg implies this)
-            $timezone = $CFG->timezone;
-        }
-    }
-
-    if(abs($timezone) <= 13) {
-        $tzfix = $timezone * 3600;
-    }
-    else {
-        $tzfix = date('Z');
-    }
-
-    return $tzfix;
-}
-
 function calendar_preferences_array() {
     return array(
         'startwday' => get_string('pref_startwday', 'calendar'),
@@ -1132,7 +1095,7 @@ function calendar_preferences_button() {
     global $CFG, $USER;
 
     // Guests have no preferences
-    if (empty($USER->id) or isguest()) {
+    if (empty($USER->id) || isguest()) {
         return '';
     }
 
@@ -1141,6 +1104,68 @@ function calendar_preferences_button() {
            "<input type=\"submit\" value=\"".get_string("preferences", "calendar")." ...\" /></form>";
 }
 
+function calendar_format_event_time($event, $now, $morehref, $usecommonwords = true) {
+    $startdate = usergetdate($event->timestart);
+    $enddate = usergetdate($event->timestart + $event->timeduration);
+    $usermidnightstart = usergetmidnight($event->timestart);
+
+    if($event->timeduration) {
+        // To avoid doing the math if one IF is enough :)
+        $usermidnightend = usergetmidnight($event->timestart + $event->timeduration);
+    }
+    else {
+        $usermidnightend = $usermidnightstart;
+    }
+
+    // OK, now to get a meaningful display...
+    // First of all we have to construct a human-readable date/time representation
+
+    if($event->timestart + $event->timeduration < $now) {
+        // It has expired, so we don't care about duration
+        $day = calendar_day_representation($event->timestart + $event->timeduration, $now, $usecommonwords);
+        $time = calendar_time_representation($event->timestart + $event->timeduration);
+
+        // This var always has the printable time representation
+        $eventtime = '<span class="dimmed_text"><a class="dimmed" href="'.calendar_get_link_href(CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $enddate['mday'], $enddate['mon'], $enddate['year']).'">'.$day.'</a> ('.$time.')</span>';
+
+    }
+    else if($event->timeduration) {
+        // It has a duration
+        if($usermidnightstart == $usermidnightend) {
+            // But it's all on the same day
+            $day = calendar_day_representation($event->timestart, $now, $usecommonwords);
+            $timestart = calendar_time_representation($event->timestart);
+            $timeend = calendar_time_representation($event->timestart + $event->timeduration);
+
+            // Set printable representation
+            $eventtime = calendar_get_link_tag($day, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $enddate['mday'], $enddate['mon'], $enddate['year']).
+                ' ('.$timestart.' -> '.$timeend.')';
+        }
+        else {
+            // It spans two or more days
+            $daystart = calendar_day_representation($event->timestart, $now, $usecommonwords);
+            $dayend = calendar_day_representation($event->timestart + $event->timeduration, $now, $usecommonwords);
+            $timestart = calendar_time_representation($event->timestart);
+            $timeend = calendar_time_representation($event->timestart + $event->timeduration);
+
+            // Set printable representation
+            $eventtime = calendar_get_link_tag($daystart, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $startdate['mday'], $startdate['mon'], $startdate['year']).
+                ' ('.$timestart.') -> '.calendar_get_link_tag($dayend, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $enddate['mday'], $enddate['mon'], $enddate['year']).
+                ' ('.$timeend.')';
+        }
+    }
+    else {
+        // It's an "instantaneous" event
+        $day = calendar_day_representation($event->timestart, $now, $usecommonwords);
+        $time = calendar_time_representation($event->timestart);
+
+        // Set printable representation
+        $eventtime = calendar_get_link_tag($day, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $startdate['mday'], $startdate['mon'], $startdate['year']).' ('.$time.')';
+    }
+
+    return $eventtime;
+}
+
 if(!function_exists('array_diff_assoc')) {
     // PHP < 4.3.0
     function array_diff_assoc($source, $diff) {
