@@ -1,4 +1,4 @@
-<?PHP // $Id: mod.php,v 1.60.2.3 2004/10/09 17:02:26 stronk7 Exp $
+<?PHP // $Id: mod.php,v 1.60.2.4 2005/02/08 01:05:50 stronk7 Exp $
 
 //  Moves, adds, updates, duplicates or deletes modules in a course
 
@@ -425,7 +425,7 @@
         $strdeletecheck = get_string("deletecheck", "", "$form->fullmodulename");
         $strdeletecheckfull = get_string("deletecheckfull", "", "$form->fullmodulename '$form->instancename'");
 
-        print_header_simple("$strdeletecheck", "$",
+        print_header_simple("$strdeletecheck", "",
                      "$strdeletecheck");
 
         print_simple_box_start("center", "60%", "#FFAAAA", 20, "noticebox");
