@@ -1,4 +1,4 @@
-<?PHP // $Id: scales.php,v 1.8 2004/05/18 17:08:41 stronk7 Exp $
+<?PHP // $Id: scales.php,v 1.8.8.4 2005/01/08 10:47:00 stronk7 Exp $
       // Allows a creator to edit custom scales, and also display help about scales
 
     require_once("../config.php");
@@ -39,11 +39,14 @@
     $stroptions = get_string("action");
     $strtype = get_string("group");
 
+    /// init this here so we can pass it by reference to every call to site_scale_used to avoid getting the courses out of the db over and over again
+    $courses = array();
+
     /// If scale data is being submitted, then save it and continue
 
     $errors = NULL;
 
-    if ($action == 'sendform') {
+    if ($action == 'sendform' and confirm_sesskey()) {
         if ($form = data_submitted()) {
             if (empty($form->name)) {
                 $errors[$scaleid]->name = true;
@@ -98,8 +101,8 @@
             error("Scale ID was incorrect");
         }
 
-        $scales_course_uses = course_scale_used($course->id,$scale->id);
-        $scales_site_uses = site_scale_used($scale->id);
+        //        $scales_course_uses = course_scale_used($course->id,$scale->id);
+        //        $scales_site_uses = site_scale_used($scale->id,$courses);
         $scalemenu = make_menu_from_list($scale->scale);
 
         print_header("$course->shortname: $strscales", "$course->fullname",
@@ -124,6 +127,9 @@
 
     //If action is edit or new, show the form
     if ($action == "edit" || $action == "new") {
+
+        $sesskey = !empty($USER->id) ? $USER->sesskey : '';
+
         //Check for teacher edit
         if (! isteacheredit($course->id)) {
             error("Only editing teachers can modify scales !");
@@ -143,7 +149,7 @@
             
         //Calculate the uses
         if ($scale->courseid == 0) {
-            $scale_uses = site_scale_used($scale->id);
+            $scale_uses = site_scale_used($scale->id,$courses);
         } else {
             $scale_uses = course_scale_used($course->id,$scale->id);
         }
@@ -216,6 +222,7 @@
         echo "<tr>";
         echo "<td colspan=2 align=\"center\">";
         echo "<input type=\"hidden\" name=\"id\" value=\"$course->id\">";
+        echo "<input type=\"hidden\" name=\"sesskey\" value=\"$sesskey\">";
         echo "<input type=\"hidden\" name=\"courseid\" value=\"$scale->courseid\">";
         echo "<input type=\"hidden\" name=\"scaleid\" value=\"$scale->id\">";
         echo "<input type=\"hidden\" name=\"action\" value=\"sendform\">";
@@ -230,7 +237,7 @@
     }
 
     //If action is delete, do it
-    if ($action == "delete") {
+    if ($action == "delete" and confirm_sesskey()) {
         //Check for teacher edit
         if (! isteacheredit($course->id)) {
             error("Only editing teachers can delete scales !");
@@ -242,7 +249,7 @@
 
         //Calculate the uses
         if ($scale->courseid == 0) {
-            $scale_uses = site_scale_used($scale->id);
+            $scale_uses = site_scale_used($scale->id,$courses);
         } else {
             $scale_uses = course_scale_used($course->id,$scale->id);
         }
@@ -263,7 +270,7 @@
     }
 
     //If action is down or up, do it
-    if ($action == "down" || $action == "up" ) {
+    if (($action == "down" || $action == "up") and confirm_sesskey()) {
         //Check for teacher edit
         if (! isadmin()) {
             error("Only administrators can move scales",$CFG->wwwroot.'/course/scales.php?id='.$course->id);
@@ -275,7 +282,7 @@
 
         //Calculate the uses
         if ($scale->courseid == 0) {
-            $scale_uses = site_scale_used($scale->id);
+            $scale_uses = site_scale_used($scale->id,$courses);
         } else {
             $scale_uses = course_scale_used($course->id,$scale->id);
         }
@@ -436,7 +443,7 @@
             if (!empty($scale->courseid)) {
                 $scales_uses = course_scale_used($course->id,$scale->id);
             } else {
-                $scales_uses = site_scale_used($scale->id);
+                $scales_uses = site_scale_used($scale->id,$courses);
             }
             $line[] = $scales_uses;
             if ($incustom) {
@@ -449,14 +456,14 @@
                 $buttons .= "<a title=\"$stredit\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=edit\"><img".
                             " src=\"$pixpath/t/edit.gif\" hspace=2 height=11 width=11 border=0></a> ";
                 if ($incustom && isadmin()) {
-                    $buttons .= "<a title=\"$strdown\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=down\"><img".
+                    $buttons .= "<a title=\"$strdown\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=down&amp;sesskey=$USER->sesskey\"><img".
                                 " src=\"$pixpath/t/down.gif\" hspace=2 height=11 width=11 border=0></a> ";
                 }
                 if (!$incustom && isadmin()) {
-                    $buttons .= "<a title=\"$strup\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=up\"><img".
+                    $buttons .= "<a title=\"$strup\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=up&amp;sesskey=$USER->sesskey\"><img".
                                 " src=\"$pixpath/t/up.gif\" hspace=2 height=11 width=11 border=0></a> ";
                 }
-                $buttons .= "<a title=\"$strdelete\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=delete\"><img".
+                $buttons .= "<a title=\"$strdelete\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=delete&amp;sesskey=$USER->sesskey\"><img".
                             " src=\"$pixpath/t/delete.gif\" hspace=2 height=11 width=11 border=0></a> ";
             }
             $line[] = $buttons;
@@ -465,7 +472,7 @@
         }
         $head = $strscale.",".$stractivities.",".$strtype.",".$stroptions;
         $table->head = explode(",",$head);
-        $size = "50%,20$,20%,10%";
+        $size = "50%,20%,20%,10%";
         $table->size = explode(",",$size);
         $align = "left,center,center,center";
         $table->align = explode(",",$align);
