@@ -1,5 +1,5 @@
-<?PHP // $Id: moodle.php,v 1.21 2004/04/27 05:13:37 moodler Exp $ 
-      // moodle.php - created with Moodle 1.3 development (2004041800)
+<?PHP // $Id$ 
+      // moodle.php - created with Moodle 1.4 development (2004081200)
 
 
 $string['action'] = '';
@@ -13,6 +13,7 @@ $string['activityreport'] = ' ';
 $string['activityselect'] = '      ';
 $string['activitysince'] = '  $a';
 $string['add'] = '';
+$string['addactivity'] = ' ';
 $string['addadmin'] = ' ';
 $string['addcreator'] = '   ';
 $string['added'] = '  $a';
@@ -25,6 +26,7 @@ $string['addingdatatoexisting'] = '  ';
 $string['addnewcategory'] = '  ';
 $string['addnewcourse'] = '   ';
 $string['addnewuser'] = '  ';
+$string['addresource'] = ' ';
 $string['address'] = '';
 $string['addstudent'] = ' ';
 $string['addteacher'] = ' ';
@@ -40,6 +42,8 @@ $string['adminhelpconfiguration'] = '   ';
 $string['adminhelpconfigvariables'] = '       ';
 $string['adminhelpcourses'] = '      ';
 $string['adminhelpedituser'] = '      ';
+$string['adminhelpenrolments'] = '       ';
+$string['adminhelpfailurelogs'] = '    ';
 $string['adminhelplanguage'] = '    ';
 $string['adminhelplogs'] = '    ';
 $string['adminhelpmanageblocks'] = '   ';
@@ -54,6 +58,8 @@ $string['adminhelpusers'] = '     ';
 $string['administration'] = ' ';
 $string['administrator'] = '';
 $string['administrators'] = '';
+$string['administratorsall'] = ' ';
+$string['administratorsandteachers'] = ' ';
 $string['advancedfilter'] = ' ';
 $string['again'] = ' ';
 $string['all'] = '';
@@ -94,6 +100,8 @@ $string['backupfilename'] = '    ';
 $string['backupfinished'] = '   ';
 $string['backupincludemoduleshelp'] = '              ';
 $string['backupkeephelp'] = '          ǿ(   ';
+$string['backuplogdetailed'] = '  ';
+$string['backuploglaststatus'] = '  ';
 $string['backuplogshelp'] = '            .';
 $string['backupnameformat'] = '     ';
 $string['backuporiginalname'] = '     ';
@@ -101,9 +109,13 @@ $string['backupsavetohelp'] = '           <br> (       )';
 $string['backupuserfileshelp'] = '       (:   )    ';
 $string['backupusershelp'] = '                ';
 $string['backupversion'] = '  ';
+$string['blockdeleteconfirm'] = '     \'$ a\'  .          .         ';
+$string['blockdeletefiles'] = '     \'$a->block\'     .    (     )          $a->directory';
+$string['blocks'] = '';
 $string['blocksetup'] = '  ';
 $string['blocksuccess'] = '$a      ';
 $string['bycourseorder'] = '   ';
+$string['byname'] = ' $a';
 $string['cancel'] = '';
 $string['categories'] = '   ';
 $string['category'] = '';
@@ -132,10 +144,15 @@ $string['closewindow'] = '  ';
 $string['comparelanguage'] = '   ';
 $string['complete'] = '';
 $string['configallowunenroll'] = '   \"\"         .               .';
+$string['configautologinguests'] = '           .';
 $string['configcountry'] = '   ,        .        .';
 $string['configdebug'] = '            .     .';
+$string['configdigestmailtime'] = '                .        (       \"corn\" ).';
+$string['configdisplayloginfailures'] = '           .';
 $string['configerrorlevel'] = '   PHP    .      .';
+$string['configfilteruploadedfiles'] = '     Moodle     (HTML)                .';
 $string['configforcelogin'] = 'ǡ           (   )    .               .';
+$string['configforceloginforprofiles'] = '       ( )        .      (\"\")                          .';
 $string['configframename'] = '          ߡ       \"\".';
 $string['configfullnamedisplay'] = '         .           \"  + \",       ,      (   ) ';
 $string['configgdversion'] = '      GD.         .         .';
@@ -176,6 +193,7 @@ $string['copyingcoursefiles'] = '   ';
 $string['copyinguserfiles'] = '  ';
 $string['copyingzipfile'] = '  ';
 $string['copyrightnotice'] = '  ';
+$string['cost'] = '';
 $string['country'] = '';
 $string['course'] = ' ';
 $string['courseavailable'] = '    ';
@@ -212,6 +230,7 @@ $string['currentcourseadding'] = '    ';
 $string['currentcoursedeleting'] = '    ';
 $string['currentlanguage'] = ' ';
 $string['currentlocaltime'] = '  ';
+$string['currentpicture'] = ' ';
 $string['currentrelease'] = '  ';
 $string['currentversion'] = ' ';
 $string['databasechecking'] = '   Moodle   $a->oldversion  $a->newversion...';
@@ -221,10 +240,12 @@ $string['databasesuccess'] = '    ';
 $string['databaseupgradebackups'] = '    $a';
 $string['databaseupgradeblocks'] = '    $a';
 $string['databaseupgrades'] = '  ';
+$string['date'] = '';
 $string['datemostrecentfirst'] = ' -  ';
 $string['datemostrecentlast'] = ' -  ';
 $string['day'] = '';
 $string['days'] = '';
+$string['decodinginternallinks'] = '  ';
 $string['defaultcoursefullname'] = '    101';
 $string['defaultcourseshortname'] = ' 101';
 $string['defaultcoursestudent'] = '';
@@ -261,16 +282,21 @@ $string['down'] = '';
 $string['downloadexcel'] = '   ';
 $string['downloadtext'] = '   ';
 $string['doyouagree'] = '     ǿ';
+$string['duplicate'] = ' ';
+$string['duplicatinga'] = '  : $a';
+$string['duplicatingain'] = '  $ a> what $ a> in';
 $string['edit'] = ' $a';
 $string['editcoursesettings'] = '   ';
+$string['editfiles'] = ' ';
 $string['editgroupprofile'] = '  ';
 $string['editinga'] = ' $a';
-$string['editmyprofile'] = '  ';
+$string['editmyprofile'] = '   ';
 $string['editsummary'] = ' ';
 $string['editthisactivity'] = '  ';
 $string['editthiscategory'] = '  ';
 $string['edituser'] = '  ';
 $string['email'] = '  ';
+$string['emailactive'] = '   ';
 $string['emailagain'] = '  ';
 $string['emailconfirm'] = '  ';
 $string['emailconfirmation'] = ' $a->firstname,
@@ -285,12 +311,18 @@ $string['emailconfirmationsubject'] = '$a  :';
 $string['emailconfirmsent'] = '   <P>    <B>$a</B>
    <P>        
    <P>      ';
+$string['emaildigest'] = '  ';
+$string['emaildigestcomplete'] = ' (     )';
+$string['emaildigestoff'] = '  (     )';
+$string['emaildigestsubjects'] = ' (      )';
 $string['emaildisable'] = '    ';
+$string['emaildisableclick'] = '        ';
 $string['emaildisplay'] = ' ';
 $string['emaildisplaycourse'] = '        ';
 $string['emaildisplayno'] = '    ';
 $string['emaildisplayyes'] = '   ';
 $string['emailenable'] = '    ';
+$string['emailenableclick'] = '        ';
 $string['emailexists'] = '    .';
 $string['emailformat'] = ' ';
 $string['emailmustbereal'] = '      ';
@@ -302,8 +334,7 @@ $a->firstname,
 $a->link
                .               
      ɡ    
-$a->admin
-';
+$a->admin';
 $string['emailpasswordconfirmationsubject'] = '$a   :';
 $string['emailpasswordconfirmsent'] = '           <b>$a</b>
 <p>      
@@ -315,8 +346,9 @@ $string['emailpasswordsent'] = '
 <p>    ǡ   
 <a href=$a->link>    </a>   ';
 $string['enable'] = '';
-$string['enrolledincourse'] = '    \"$a\"';
-$string['enrolledincoursenot'] = '     \"$a\"';
+$string['encryptedcode'] = ' ';
+$string['enrolledincourse'] = '    ';
+$string['enrolledincoursenot'] = '     ';
 $string['enrolmentconfirmation'] = '        
 <br />    ߿';
 $string['enrolmentkey'] = ' ';
@@ -324,11 +356,18 @@ $string['enrolmentkeyfrom'] = '    \' \' -     <BR>
        $a';
 $string['enrolmentkeyhint'] = '   .   <BR>
 (  -    \'$a\'';
+$string['enrolmentnew'] = '   $a';
+$string['enrolmentnointernal'] = '    ';
+$string['enrolmentnotyet'] = '         </ br> $a';
+$string['enrolments'] = '';
+$string['enrolperiod'] = ' ';
 $string['entercourse'] = '    ';
 $string['enteremailaddress'] = '          .';
+$string['entries'] = '';
 $string['error'] = '';
 $string['errortoomanylogins'] = '     .   .';
 $string['errorwhenconfirming'] = '        .                  ǡ           ';
+$string['everybody'] = '';
 $string['executeat'] = '  ';
 $string['existing'] = '';
 $string['existingadmins'] = ' ';
@@ -339,6 +378,7 @@ $string['existingcreators'] = '   ';
 $string['existingstudents'] = ' ';
 $string['existingteachers'] = ' ';
 $string['feedback'] = '';
+$string['file'] = '';
 $string['filemissing'] = '$a  ';
 $string['files'] = '';
 $string['filesfolders'] = ' / ';
@@ -387,6 +427,7 @@ $string['grades'] = '';
 $string['group'] = '';
 $string['groupadd'] = '  ';
 $string['groupaddusers'] = '   ';
+$string['groupfor'] = '';
 $string['groupinfo'] = '   ';
 $string['groupinfomembers'] = '   ';
 $string['groupinfopeople'] = '   ';
@@ -423,6 +464,9 @@ $string['helpsummaries'] = '  ';
 $string['helptext'] = '  ';
 $string['helpwiki'] = '    ';
 $string['helpwriting'] = ' ';
+$string['hiddensections'] = ' ';
+$string['hiddensectionscollapsed'] = '       ';
+$string['hiddensectionsinvisible'] = '    ';
 $string['hide'] = '';
 $string['hidepicture'] = ' ';
 $string['hits'] = '';
@@ -449,10 +493,12 @@ $string['included'] = '';
 $string['includelogentries'] = '  ';
 $string['includemodules'] = ' ';
 $string['includeneededusers'] = '   ';
+$string['includenoneusers'] = '  ';
 $string['includeuserfiles'] = '  ';
 $string['institution'] = '';
 $string['invalidemail'] = '    ';
 $string['invalidlogin'] = '      ѡ   .';
+$string['ip_address'] = ' IP';
 $string['jumpto'] = ' ...';
 $string['keep'] = '';
 $string['langltr'] = '     ';
@@ -472,11 +518,12 @@ $string['list'] = '';
 $string['listfiles'] = '   $a';
 $string['listofallpeople'] = '  ';
 $string['livelogs'] = '   ';
-$string['locale'] = 'ar_AR';
+$string['locale'] = 'en';
 $string['location'] = '';
 $string['loggedinas'] = '   $a';
 $string['loggedinnot'] = '  .';
 $string['login'] = '';
+$string['login_failure_logs'] = '   ';
 $string['loginas'] = ' ';
 $string['loginguest'] = '  ';
 $string['loginsite'] = '  ';
@@ -490,7 +537,7 @@ $string['loginsteps'] = ' !                 :
    <LI>        .
    <LI>            (    )               .
    <LI>    \'\' \'\' -      .   \'\'\'\'   .   
-   <LI>           &quot; &quot;   .
+   <LI>           \" \"   .
    </OL>';
 $string['loginstepsnone'] = '!<P>        .<P>              !<P>             .';
 $string['loginto'] = '  $a';
@@ -541,6 +588,7 @@ $string['moduledeletefiles'] = '     \'$a->module\'  .             :$a->director
 $string['modulesetup'] = '   ';
 $string['modulesuccess'] = '$a     ';
 $string['moodleversion'] = ' ';
+$string['more'] = '';
 $string['mostrecently'] = '';
 $string['move'] = '';
 $string['movecategoryto'] = '  :';
@@ -576,8 +624,7 @@ $string['newpasswordtext'] = ' $a->firstname,
    $a->link
               .    ߡ          .
   \'$a->sitename\' ,
-$a->signoff
-';
+$a->signoff';
 $string['newpicture'] = '  ';
 $string['newsitem'] = ' ';
 $string['newsitems'] = ' ';
@@ -586,6 +633,7 @@ $string['newuser'] = ' ';
 $string['newusers'] = ' ';
 $string['next'] = '';
 $string['no'] = '';
+$string['nobody'] = ' ';
 $string['nocoursesfound'] = '         \'$a\'';
 $string['nocoursesyet'] = '     ';
 $string['noexistingadmins'] = '         ';
@@ -645,7 +693,7 @@ $string['passwordsenttext'] = '   <P>     $a->email.
    <P>    ɡ   
    <A HREF=$a->link>         </A>.';
 $string['people'] = '';
-$string['personalprofile'] = '  ';
+$string['personalprofile'] = ' ';
 $string['phone'] = '';
 $string['phpinfo'] = ' PHP';
 $string['popupwindow'] = '    ';
@@ -686,6 +734,7 @@ $string['rename'] = ' ';
 $string['renamefileto'] = '  <b>$a</b> ';
 $string['required'] = '';
 $string['requireskey'] = '      ';
+$string['requirespayment'] = '        ';
 $string['resortcoursesbyname'] = '   ';
 $string['resources'] = '';
 $string['restore'] = '';
@@ -740,11 +789,14 @@ $string['showrecent'] = '  ';
 $string['showreports'] = '  ';
 $string['showtheselogs'] = ' ';
 $string['since'] = '';
+$string['sincelast'] = '  ';
 $string['site'] = '';
+$string['siteerrors'] = ' ';
 $string['sitefiles'] = ' ';
 $string['sitelogs'] = '  ';
 $string['sitenews'] = ' ';
 $string['sites'] = '';
+$string['sitesection'] = '  ';
 $string['sitesettings'] = '  ';
 $string['size'] = '';
 $string['sizeb'] = '';
@@ -755,6 +807,7 @@ $string['socialheadline'] = '  -  ';
 $string['someallowguest'] = '     ';
 $string['someerrorswerefound'] = '     ɡ         .';
 $string['sortby'] = ' ';
+$string['specifyname'] = '   ';
 $string['startdate'] = '   ';
 $string['startsignup'] = '  ';
 $string['state'] = ' / ';
@@ -764,6 +817,7 @@ $string['strftimedateshort'] = '%%d %%B';
 $string['strftimedatetime'] = '%%d %%B %%Y, %%I:%%M %%p';
 $string['strftimedaydate'] = '%%A, %%d %%B %%Y';
 $string['strftimedaydatetime'] = '%%A, %%d %%B %%Y, %%I:%%M %%p';
+$string['strftimemonthyear'] = '%%B %%Y';
 $string['strftimerecent'] = '%%d %%b, %%H:%%M';
 $string['strftimerecentfull'] = '%%a, %%d %%b %%Y, %%I:%%M %%p';
 $string['strftimetime'] = '%%I:%%M %%p';
@@ -804,9 +858,12 @@ $string['turneditingoff'] = ' ';
 $string['turneditingon'] = ' ';
 $string['undecided'] = ' ';
 $string['unenrol'] = ' ';
+$string['unenrolallstudents'] = '   ';
+$string['unenrolallstudentssure'] = '             ';
 $string['unenrolme'] = '   $a';
 $string['unenrolsure'] = '       $a    ?';
 $string['unknowncategory'] = '  ';
+$string['unlimited'] = ' ';
 $string['unpacking'] = '  $a';
 $string['unsafepassword'] = '    -  ';
 $string['unusedaccounts'] = '      $a     ';
@@ -829,6 +886,7 @@ $string['uploadnotallowed'] = '   ';
 $string['uploadproblem'] = '      . $a(   ?)';
 $string['uploadthisfile'] = '  ';
 $string['uploadusers'] = ' ';
+$string['usedinnplaces'] = '  $a ';
 $string['user'] = '';
 $string['userconfirmed'] = '  $a';
 $string['userdata'] = ' ';
@@ -838,7 +896,7 @@ $string['userfiles'] = ' ';
 $string['username'] = ' ';
 $string['usernameexists'] = '      ';
 $string['usernotconfirmed'] = '    $a';
-$string['userprofilefor'] = '   $a';
+$string['userprofilefor'] = ' $a ';
 $string['users'] = '';
 $string['usersnew'] = ' ';
 $string['userzones'] = ' ';
