@@ -1,11 +1,18 @@
-<?PHP // $Id: admin.php,v 1.2 2004/04/06 10:12:47 carlesbellver Exp $ 
-      // admin.php - created with Moodle 1.3 development (2004032800)
+<?PHP // $Id$ 
+      // admin.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)
 
 
+$string['blockinstances'] = 'Instncies';
+$string['blockmultiple'] = 'Mltiple';
 $string['cachetext'] = 'Durada de la memria cau de text';
+$string['change'] = 'Canvia';
 $string['filteruploadedfiles'] = 'Filtrar fitxers penjats';
 $string['upgradelogs'] = 'Per a disposar de totes les funcionalitats, els vostres registres s\'han d\'actualitzar. <a href=\"$a\">Ms informaci</a>';
 $string['upgradelogsinfo'] = 'S\'han introdut alguns canvis en la manera d\'emmagatzemar els registres. Per tal de poder veure tots els vostres registres vells per activitat, els vostres registres vells s\'han d\'actualitzar. Depenent del vostre servidor aix pot trigar una bona estona (unes quantes hores) i en una installaci gran pot carregar una mica la base de dades. Una vegada hgeu engegat aquest procs haureu de deixar que acabi (mantenint la finestra del navegador oberta). No us amoneu: el vostre lloc seguir actiu per als usuaris mentre els registres s\'actualitzen. <br /><br />Voleu actualitzar els registres ara?';
+$string['upgradesure'] = 'Els vostres fitxers de Moodle han canviat i esteu a punt d\'actualitzar automticament el servidor a aquesta versi:
+<p><b>$a</b></p>
+<p>Desprs de fer aix no podreu tornar enrere.</p> 
+<p>Esteu segur que voleu actualitzar aquest servidor a aquesta versi?</p>';
 $string['upgradinglogs'] = 'S\'estan actualitzant els registres';
 
 ?>
