@@ -1,18 +1,23 @@
-<?PHP // $Id: error.php,v 1.7 2004/03/20 12:21:08 moodler Exp $ 
+<?php // $Id$ 
       // error.php - created with Moodle 1.2 development (2003122600)
 
 $string['coursegroupunknown'] = 'Course corresponding to group $a not specified';
+$string['confirmsesskeybad'] = 'Sorry, but your session key could not be confirmed to carry out this action.  This security feature prevents against accidental or malicious execution of important functions in your name.  Please make sure you really wanted to execute this function.';
 $string['erroronline'] = 'Error on line $a';
 $string['fieldrequired'] = '\"$a\" is a required field';
+$string['filenotfound'] = 'Sorry, the requested file could not be found';
 $string['groupalready'] = 'User already belongs to group $a';
 $string['groupunknown'] = 'Group $a not associated to specified course';
 $string['invalidfieldname'] = '\"$a\" is not a valid field name';
 $string['missingfield'] = 'Field \"$a\" is missing';
 $string['modulerequirementsnotmet'] = 'Module \"$a->modulename\" ($a->moduleversion) could not be installed.  It requires a newer version of Moodle (currently you are using $a->currentmoodle, you need $a->requiremoodle).';
 $string['notavailable'] = 'That is not currently available';
+$string['processingstops'] = 'Processing stops here. Remaining records ignored.';
 $string['restricteduser'] = 'Sorry, but your current account \"$a\" is restricted from doing that.';
+$string['sessionipnomatch'] = 'Sorry, but your IP number seems to have changed from when you first logged in.  This security feature prevents crackers stealing your identity while logged in to this site.  Normal users should not be seeing this message - please ask the site administrator for help.';
 $string['unknowncourse'] = 'Unknown course named \"$a\"';
 $string['usernotaddederror'] = 'User \"$a\" not added - unknown error';
 $string['usernotaddedregistered'] = 'User \"$a\" not added - already registered';
+$string['usernotavailable'] = 'The details of this user are not available to you.';
 
 ?>
