@@ -1,5 +1,5 @@
-<?PHP // $Id: moodle.php,v 1.27 2004/05/10 15:55:44 stronk7 Exp $ 
-      // moodle.php - created with Moodle 1.2 Beta + (2004030702)
+<?PHP // $Id$ 
+      // moodle.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004110200)
 
 
 $string['action'] = 'Accin';
@@ -304,10 +304,10 @@ $string['emailpasswordsent'] = 'Gracias por confirmar el cambio de contrasea.
 $string['enable'] = 'Permitir';
 $string['enrolmentconfirmation'] = 'Est a punto de inscribirse como alumno en este curso. <br />Est seguro de que desea hacerlo?';
 $string['enrolmentkey'] = 'Clave de acceso';
-$string['enrolmentkeyfrom'] = 'Este curso requiere el uso de una \'clave de acceso\'. Si ha sido admitido<BR>
+$string['enrolmentkeyfrom'] = 'Este curso requiere el uso de una \'clave de acceso\'. Si ha sido admitido<br />
 
 en l y no le hemos enviado la clave, por favor hganoslo saber.';
-$string['enrolmentkeyhint'] = 'Esta \'clave de acceso\' es incorrecta, por favor intntelo de nuevo<BR>
+$string['enrolmentkeyhint'] = 'Esta \'clave de acceso\' es incorrecta, por favor intntelo de nuevo<br />
 
 (Una pista: comienza con \'$a\')';
 $string['entercourse'] = 'Clic aqu para entrar al curso';
@@ -356,10 +356,10 @@ $string['gd1'] = 'GD 1.x est instalado';
 $string['gd2'] = 'GD 2.x est instalado';
 $string['gdneed'] = 'GD debe estar instalado para ver este grfico';
 $string['gdnot'] = 'GD no est instalado';
-$string['gpl'] = 'Copyright (C) 2001-2002  Martin Dougiamas  (http://dougiamas.com)<BR> Traduccin: Antonio J. Navarro Vergara (http://www.sextaisla.com)
+$string['gpl'] = 'Copyright (C) 2001-2002  Martin Dougiamas  (http://dougiamas.com)<br /> Traduccin: Antonio J. Navarro Vergara (http://www.sextaisla.com)
 Este programa es software gratuito. Ud. puede redistribuirlo y/o modificarlo bajo los trminos de GNU General Public License segn la publicacin de The Free Software Foundation; incluso la versin 2 o alguna posterior.
 
-<BR>
+<br />
 
 Para ms detalles vea: http://www.gnu.org/copyleft/gpl.html';
 $string['grade'] = 'Calificacin';
@@ -442,7 +442,7 @@ $string['loginsteps'] = 'Para tener acceso completo a los cursos necesita crear
    <LI>Rellene la <A HREF=$a>Solicitud de alta</A>.
    <LI>El sistema le enviar un correo electrnico para verificar que su direccin es correcta.
    <LI>Lea el correo y confirme su alta.
-   <LI>Para entrar en los cursos se le pedir una &quot;clave de acceso&quot;, que se le enviar cuando se matricule en los mismos.
+   <LI>Para entrar en los cursos se le pedir una \"clave de acceso\", que se le enviar cuando se matricule en los mismos.
    <LI>A partir de ese momento no necesitar utilizar ms que su nombre y contrasea.
    </OL>';
 $string['loginstepsnone'] = 'Hola.<P>Para poder tener acceso completo a los cursos necesita crear
@@ -726,7 +726,8 @@ $string['theme'] = 'Entorno';
 $string['themes'] = 'Entornos';
 $string['themesaved'] = 'Se ha grabado el nuevo entorno';
 $string['thischarset'] = 'iso-8859-1';
-$string['thislanguage'] = 'Espaol - Espaa';
+$string['thisdirection'] = 'ltr';
+$string['thislanguage'] = 'Espa&#241;ol - Espa&#241;a';
 $string['time'] = 'Hora';
 $string['timezone'] = 'Zona horaria';
 $string['to'] = 'A';
