@@ -1,13 +1,23 @@
-<?PHP // $Id: admin.php,v 1.3 2004/03/24 15:04:58 paca70 Exp $ 
-      // admin.php - created with Moodle 1.2 Beta +++ (2004031300)
+<?PHP // $Id$ 
+      // admin.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)
 
 
+$string['blockinstances'] = 'Ilmentymt';
+$string['blockmultiple'] = 'Monenkertainen';
 $string['cachetext'] = 'Tekstivlimuistin kesto';
+$string['change'] = 'muutos';
 $string['filteruploadedfiles'] = 'Suodata lhetettyj tiedostoja';
+$string['thischarset'] = 'iso-8859-1';
+$string['thisdirection'] = 'ltr';
+$string['thislanguage'] = 'Suomi';
 $string['upgradelogs'] = 'Tapahtumalokien sisllt pit pivitt uuteen muotoon. <a href=\"$a\">Listietoja</a>';
 $string['upgradelogsinfo'] = 'Tapahtumalokien tallennuksessa on tapahtunut muutoksia. Jotta voisit tarkastella lokeja uudella tavalla, vanhat lokimerkinnt pit pivitt uuteen muotoon. Tm tapahtuu automaattisesti eik hiritse sivustosi muuta kytt. Riippuen sivustosi koosta thn saattaa kuitenkin menn aikaa jopa useita tunteja. Kun aloitat pivityksen, pit se antaan menn loppuun asti keskeyttmtt.
 <br /><br />
 Haluatko pivitt lokit nyt?';
+$string['upgradesure'] = 'Moodlen asennustiedostot ovat muuttuneet, jrjestelm tullaan pivittmn uuteen versioon automaattisesti. Uusi version on:
+ <p><b>$a</b></p>
+<p>Kun aloitat pivittmisen et voi en palata takaisin aiempaan versioon.</p>
+<p>Oletko varma ett haluat pivitt palvelimen?</p>';
 $string['upgradinglogs'] = 'Pivitetn tapahtumalokeja';
 
 ?>
