@@ -1,5 +1,5 @@
-<?PHP // $Id: pix.php,v 1.2 2004/03/24 15:05:00 paca70 Exp $ 
-      // pix.php - created with Moodle 1.2 Beta +++ (2004031300)
+<?PHP // $Id$ 
+      // pix.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)
 
 
 $string['angry'] = 'Vihainen';
@@ -18,6 +18,9 @@ $string['shy'] = 'Ujo';
 $string['sleepy'] = 'Vsynyt';
 $string['smiley'] = 'Hymy';
 $string['surprise'] = 'Yllttynyt';
+$string['thischarset'] = 'iso-8859-1';
+$string['thisdirection'] = 'ltr';
+$string['thislanguage'] = 'Suomi';
 $string['thoughtful'] = 'Ajattelevainen';
 $string['tongueout'] = 'Nytt kielt';
 $string['wideeyes'] = 'Silmt suurina';
