@@ -1,5 +1,5 @@
-<?PHP // $Id: pix.php,v 1.1 2004/03/06 03:34:40 moodler Exp $ 
-      // pix.php - created with Moodle 1.2 development (2004020300)
+<?PHP // $Id$ 
+      // pix.php - created with Moodle 1.4.1 (2004083101)
 
 
 $string['angry'] = 'En colre';
@@ -13,11 +13,13 @@ $string['dead'] = 'Mort';
 $string['evil'] = 'Dmoniaque';
 $string['kiss'] = 'Baiser';
 $string['mixed'] = 'Indcis';
+$string['parentlanguage'] = 'fr';
 $string['sad'] = 'Triste';
 $string['shy'] = 'Gn';
 $string['sleepy'] = 'Endormi';
 $string['smiley'] = 'Souriant';
 $string['surprise'] = 'Surpris';
+$string['thisdirection'] = 'ltr';
 $string['thoughtful'] = 'Pensif';
 $string['tongueout'] = 'Langue tire';
 $string['wideeyes'] = 'Yeux grands ouverts';
