@@ -1,4 +1,4 @@
-<?PHP  //$Id: mysql.php,v 1.105.2.10 2004/11/24 02:20:43 martinlanghoff Exp $
+<?PHP  //$Id: mysql.php,v 1.105.2.12 2005/02/08 20:33:12 defacer Exp $
 //
 // This file keeps track of upgrades to Moodle.
 //
@@ -958,7 +958,16 @@ function main_upgrade($oldversion=0) {
         modify_database('','ALTER TABLE prefix_user_teachers DROP INDEX courseuserid;');
         modify_database('','ALTER TABLE prefix_user_teachers ADD UNIQUE INDEX courseuserid(course,userid);');        
     } 
-       
+
+    if ($oldversion < 2004083133) {
+        fix_course_sortorder(0, 1, 1);
+    }   
+
+    if ($oldversion < 2004083134) {
+        // Expand module column to max 20 chars
+        table_column('log','module','module','varchar','20','','','not null');
+    }
+
     return $result;
     
 }
