@@ -1,4 +1,4 @@
-<?PHP  //$Id: postgres7.php,v 1.77 2004/05/17 06:52:06 paca70 Exp $
+<?PHP  //$Id: postgres7.php,v 1.89.2.13 2005/02/01 01:35:18 martinlanghoff Exp $
 //
 // This file keeps track of upgrades to Moodle.
 // 
@@ -227,11 +227,7 @@ function main_upgrade($oldversion=0) {
 
     if ($oldversion < 2003080700) {
         notify("Cleaning up categories and course ordering...");
-        if ($categories = get_categories()) {
-            foreach ($categories as $category) {
-                fix_course_sortorder($category->id);
-            }
-        }
+        fix_course_sortorder();
     }
 
 
@@ -507,8 +503,219 @@ function main_upgrade($oldversion=0) {
         }
     }
 
-    return $result;
+    if ($oldversion < 2004052800) {     /// First version tagged "1.4 development", version.php 1.227
+        set_config('siteblocksadded', true);   /// This will be used later by the block upgrade
+    }
 
+    if ($oldversion < 2004053000) {     /// set defaults for site course
+        $site = get_site();
+        set_field('course', 'numsections', 0, 'id', $site->id);
+        set_field('course', 'groupmodeforce', 1, 'id', $site->id);
+        set_field('course', 'teacher', get_string('administrator'), 'id', $site->id);
+        set_field('course', 'teachers', get_string('administrators'), 'id', $site->id);
+        set_field('course', 'student', get_string('user'), 'id', $site->id);
+        set_field('course', 'students', get_string('users'), 'id', $site->id);
+    }
+
+    if ($oldversion < 2004060100) {
+        set_config('digestmailtime', 0);
+        table_column('user', "", 'maildigest', 'smallint', '1', '', '0', 'not null', 'mailformat');
+    }
+
+    if ($oldversion < 2004062400) {
+        table_column('user_teachers', "", 'timeend', 'int', '10', 'unsigned', '0', 'not null', 'editall');
+        table_column('user_teachers', "", 'timestart', 'int', '10', 'unsigned', '0', 'not null', 'editall');
+    }
+
+    if ($oldversion < 2004062401) {
+        table_column('course', '', 'idnumber', 'varchar', '100', '', '', 'not null', 'shortname');
+        execute_sql('UPDATE '.$CFG->prefix.'course SET idnumber = shortname');   // By default
+    }
+
+    if ($oldversion < 2004062600) {
+        table_column('course', '', 'cost', 'varchar', '10', '', '', 'not null', 'lang');
+    }
+
+    if ($oldversion < 2004072900) {
+        table_column('course', '', 'enrolperiod', 'int', '10', 'unsigned', '0', 'not null', 'startdate');
+    }
+
+    if ($oldversion < 2004072901) {  // Fixing error in schema
+        if ($record = get_record('log_display', 'module', 'course', 'action', 'update')) {
+            delete_records('log_display', 'module', 'course', 'action', 'update');
+            insert_record('log_display', $record, false, 'module');
+        }
+    }
+
+    if ($oldversion < 2004081200) {  // Fixing version errors in some blocks
+        set_field('blocks', 'version', 2004081200, 'name', 'admin');
+        set_field('blocks', 'version', 2004081200, 'name', 'calendar_month');
+        set_field('blocks', 'version', 2004081200, 'name', 'course_list');
+    }
+
+    if ($oldversion < 2004081500) {  // Adding new "auth" field to user table to allow more flexibility
+        table_column('user', '', 'auth', 'varchar', '20', '', 'manual', 'not null', 'id');
+
+        execute_sql("UPDATE {$CFG->prefix}user SET auth = 'manual'");  // Set everyone to 'manual' to be sure
+
+        if ($admins = get_admins()) {   // Set all the NON-admins to whatever the current auth module is
+            $adminlist = array();
+            foreach ($admins as $user) {
+                $adminlist[] = $user->id; 
+            }
+            $adminlist = implode(',', $adminlist);
+            execute_sql("UPDATE {$CFG->prefix}user SET auth = '$CFG->auth' WHERE id NOT IN ($adminlist)");
+        }
+    }
+
+    if ($oldversion < 2004082900) {  // Make sure guest is "manual" too.
+        set_field('user', 'auth', 'manual', 'username', 'guest');
+    }
+
+    if ($oldversion < 2004083127) {  // Update any users/courses using wrongly-named lang pack
+        execute_sql("UPDATE {$CFG->prefix}user SET lang = 'mi_nt' WHERE lang = 'ma_nt'");
+        execute_sql("UPDATE {$CFG->prefix}course SET lang = 'mi_nt' WHERE lang = 'ma_nt'");
+    }
+
+    if ($oldversion < 2004083128) { // add indexes.
+        modify_database("", "CREATE INDEX prefix_user_idnumber_idx ON prefix_user (idnumber);");        
+        modify_database("", "CREATE INDEX prefix_user_auth_idx ON prefix_user (auth);");        
+    }
+
+    if ($oldversion < 2004083128) { // add indexes
+        modify_database("","CREATE INDEX {$CFG->prefix}course_idnumber_idx ON {$CFG->prefix}course (idnumber);" );
+        modify_database("","CREATE INDEX {$CFG->prefix}course_shortname_idx ON {$CFG->prefix}course (shortname);" );
+        modify_database("","CREATE INDEX {$CFG->prefix}user_students_userid_idx ON {$CFG->prefix}user_students (userid);");
+        modify_database("","CREATE INDEX {$CFG->prefix}user_teachers_userid_idx ON {$CFG->prefix}user_teachers (userid);");
+    }
+
+    if ($oldversion < 2004083128) { // add an index to event for timestart and timeduration
+        modify_database('','CREATE INDEX prefix_event_timestart_idx ON prefix_event (timestart);');
+        modify_database('','CREATE INDEX prefix_event_timeduration_idx ON prefix_event (timeduration);');
+    }
+
+    if ($oldversion < 2004083128) { //add indexes on modules and course_modules
+        modify_database('','CREATE INDEX prefix_course_modules_visible_idx ON prefix_course_modules (visible);');
+        modify_database('','CREATE INDEX prefix_course_modules_course_idx ON prefix_course_modules (course);');
+        modify_database('','CREATE INDEX prefix_course_modules_module_idx ON prefix_course_modules (module);');
+        modify_database('','CREATE INDEX prefix_course_modules_instance_idx ON prefix_course_modules (instance);');
+        modify_database('','CREATE INDEX prefix_course_modules_deleted_idx ON prefix_course_modules (deleted);');
+        modify_database('','CREATE INDEX prefix_modules_name_idx ON prefix_modules (name);');
+    }
+
+    if ($oldversion < 2004083128) { // add an index on the groups_members table
+        modify_database('','CREATE INDEX prefix_groups_members_userid_idx ON prefix_groups_members (userid);');
+    }
+
+   
+    if ($oldversion < 2004083128) { // add an index on user students timeaccess (used for sorting)
+        modify_database('','CREATE INDEX prefix_user_students_timeaccess_idx ON prefix_user_students (timeaccess);');
+    }
+
+    if ($oldversion < 2004083128) { 
+        modify_database('','CREATE INDEX prefix_course_sections_coursesection_idx ON prefix_course_sections (course,section);');
+        modify_database('','CREATE INDEX prefix_scale_courseid_idx ON prefix_scale (courseid);');
+        modify_database('','CREATE INDEX prefix_user_admins_userid_idx ON prefix_user_admins (userid);');
+        modify_database('','CREATE INDEX prefix_user_coursecreators_userid_idx ON prefix_user_coursecreators (userid);');
+    }
+
+    if ($oldversion < 2004083128) { // make new indexes on user table.
+        fix_course_sortorder(0,0,1);
+        modify_database('', "DROP INDEX prefix_course_category_idx;");
+        modify_database('', "CREATE UNIQUE INDEX prefix_course_category_sortorder_uk ON prefix_course(category,sortorder)"); 
+        modify_database("","CREATE INDEX prefix_user_deleted_idx ON prefix_user (deleted)");
+        modify_database("","CREATE INDEX prefix_user_confirmed_idx ON prefix_user (confirmed)");
+        modify_database("","CREATE INDEX prefix_user_firstname_idx ON prefix_user (firstname)");
+        modify_database("","CREATE INDEX prefix_user_lastname_idx ON prefix_user (lastname)");
+        modify_database("","CREATE INDEX prefix_user_city_idx ON prefix_user (city)");
+        modify_database("","CREATE INDEX prefix_user_country_idx ON prefix_user (country)");
+        modify_database("","CREATE INDEX prefix_user_lastaccess_idx ON prefix_user (lastaccess)");
+    }
+
+    if ($oldversion < 2004083128) { // one more index for email (for sorting)
+       modify_database('','CREATE INDEX prefix_user_email_idx ON prefix_user (email);');
+    }
+
+    if ($oldversion < 2004083129) { // Undoing some module version mess from recent upgrade
+        if (get_field('modules', 'version', 'name', 'assignment') == '2004111200') {
+            set_field('modules', 'version', 2004060401, 'name', 'assignment');
+        }
+        if (get_field('modules', 'version', 'name', 'attendance') == '2004111200') {
+            set_field('modules', 'version', 2004060401, 'name', 'attendance');
+        }
+        if (get_field('modules', 'version', 'name', 'chat') == '2004121100') {
+            set_field('modules', 'version', 2004060401, 'name', 'chat');
+        }
+        if (get_field('modules', 'version', 'name', 'choice') == '2004111200') {
+            set_field('modules', 'version', 2004070103, 'name', 'choice');
+        }
+        if (get_field('modules', 'version', 'name', 'dialogue') == '2004111000') {
+            set_field('modules', 'version', 2004060401, 'name', 'dialogue');
+        }
+        if (get_field('modules', 'version', 'name', 'exercise') == '2004111200') {
+            set_field('modules', 'version', 2004062301, 'name', 'exercise');
+        }
+        if (get_field('modules', 'version', 'name', 'forum') == '2004111200') {
+            set_field('modules', 'version', 2004081801, 'name', 'forum');
+        }
+        if (get_field('modules', 'version', 'name', 'glossary') == '2004111200') {
+            set_field('modules', 'version', 2004080932, 'name', 'glossary');
+        }
+    }
+
+    if ($oldversion < 2004083130) { // update log display to use correct postgres friendly sql
+        execute_sql("UPDATE {$CFG->prefix}log_display SET field='firstname||\' \'||lastname' WHERE module='user' AND action='view' AND mtable='user'");
+        execute_sql("UPDATE {$CFG->prefix}log_display SET field='firstname||\' \'||lastname' WHERE module='course' AND action='user report' AND mtable='user'");
+
+        /// Delete duplicate enrolments 
+        /// and then tell the database course,userid is a unique combination
+        if ($users = get_records_select("user_students", "userid > 0 GROUP BY course, userid ".
+                                        "HAVING count(*) > 1", "", "max(id) as id, userid, course ,count(*)")) {
+            foreach ($users as $user) {
+                delete_records_select("user_students", "userid = '$user->userid' ".
+                                     "AND course = '$user->course' AND id <> '$user->id'");
+            }
+        }
+        flush();
+        
+        execute_sql("DROP INDEX {$CFG->prefix}user_students_courseuserid_idx ", false);
+        execute_sql("DROP INDEX {$CFG->prefix}user_students_courseuserid_uk  ", false);
+        modify_database('','CREATE UNIQUE INDEX prefix_user_students_courseuserid_uk ON prefix_user_students (course,userid);');        
+
+        /// Delete duplicate teacher enrolments 
+        /// and then tell the database course,userid is a unique combination
+        if ($users = get_records_select("user_teachers", "userid > 0 GROUP BY course, userid ".
+                                        "HAVING count(*) > 1", "", "max(id) as id, userid, course ,count(*)")) {
+            foreach ($users as $user) {
+                delete_records_select("user_teachers", "userid = '$user->userid' ".
+                                     "AND course = '$user->course' AND id <> '$user->id'");
+            }
+        }
+        flush();
+
+        execute_sql("DROP INDEX {$CFG->prefix}user_teachers_courseuserid_idx ", false);
+        execute_sql("DROP INDEX {$CFG->prefix}user_teachers_courseuserid_uk  ", false);
+        modify_database('','CREATE UNIQUE INDEX prefix_user_teachers_courseuserid_uk ON prefix_user_teachers (course,userid);');        
+
+        // some postgres databases may have a non-unique index mislabeled unique.
+        fix_course_sortorder(0,0,1);
+        execute_sql("DROP INDEX {$CFG->prefix}course_category_sortorder_uk  ", false);
+        execute_sql("DROP INDEX {$CFG->prefix}course_category_idx  ", false);
+        modify_database('', "CREATE UNIQUE INDEX prefix_course_category_sortorder_uk ON prefix_course(category,sortorder);");
+        
+        // odd! username was missing its unique index!
+        // first silently drop it just in case...
+        execute_sql("ALTER TABLE {$CFG->prefix}user DROP CONSTRAINT {$CFG->prefix}user_username_uk;", false); 
+        execute_sql("DROP INDEX {$CFG->prefix}user_username_uk", false);
+        modify_database('', "CREATE UNIQUE INDEX prefix_user_username_uk ON prefix_user (username);");
+
+    } 
+
+    if ($oldversion < 2004083133) {
+        fix_course_sortorder(0, 1, 1);
+    } 
+    
+    return $result;
 }
 
 ?>
