@@ -1,4 +1,4 @@
-<?PHP // $Id: index.php,v 1.45.2.4 2004/12/19 14:10:03 moodler Exp $
+<?PHP // $Id: index.php,v 1.45.2.5 2005/01/12 11:01:31 defacer Exp $
 
     require_once("../config.php");
     optional_variable($loginguest, false); // determines whether visitors are logged in as guest automatically
@@ -56,7 +56,7 @@
             }
             $USER->loggedin = true;
             $USER->site     = $CFG->wwwroot;     // for added security, store the site in the session
-            $USER->sesskey  = random_string(10); // for added security, used to check script parameters
+            set_user_sesskey();                  // for added security, used to check script parameters
             
             if ($USER->username == "guest") {
                 $USER->lang       = $CFG->lang;               // Guest language always same as site
