@@ -1,4 +1,4 @@
-<?PHP  // $Id: lib.php,v 1.68.2.2 2004/11/07 15:24:49 moodler Exp $
+<?PHP  // $Id: lib.php,v 1.68.2.3 2005/01/13 02:55:36 moodler Exp $
 
 require_once("$CFG->dirroot/files/mimetypes.php");
 
@@ -765,7 +765,7 @@ function assignment_print_recent_mod_activity($activity, $course, $detail=false)
 
     }
 
-    if (isteacher($USER)) {
+    if (isteacher($course)) {
         $grades = "(" .  $activity->content->grade . " / " . $activity->content->maxgrade . ") ";
 
         $assignment->id = $activity->instance;
