@@ -1,4 +1,4 @@
-<?PHP // $Id: post.php,v 1.40.4.1 2004/06/03 13:07:46 moodler Exp $
+<?PHP // $Id: post.php,v 1.51.2.3 2004/11/23 03:40:32 moodler Exp $
 
 //  Edit and save a new post to a discussion
 
@@ -10,9 +10,20 @@
         error(get_string("noguestpost", "forum"), $_SERVER["HTTP_REFERER"]);
     }
 
-    require_login();   // Script is useless unless they're logged in
+    require_login(0, false);   // Script is useless unless they're logged in
 
     if ($post = data_submitted()) {
+        if (empty($post->course)) {
+            error('No course was defined!');
+        }
+
+        if (!$course = get_record('course', 'id', $post->course)) {
+            error('Could not find specified course!');
+        }
+
+        if (!empty($course->lang)) {           // Override current language
+            $CFG->courselang = $course->lang;
+        }
 
         if (empty($SESSION->fromurl)) {
             $errordestination = "$CFG->wwwroot/mod/forum/view.php?f=$post->forum";
@@ -21,13 +32,12 @@
         }
 
         $post->subject = strip_tags($post->subject, '<lang>');        // Strip all tags except lang
-        $post->subject = break_up_long_words($post->subject);
 
-        $post->message = clean_text($post->message, $post->format);   // Clean up any bad tags
+        //$post->message = clean_text($post->message, $post->format);   // Clean up any bad tags
 
         $post->attachment = isset($_FILES['attachment']) ? $_FILES['attachment'] : NULL;
 
-        if (!$cm = get_coursemodule_from_instance("forum", $post->forum, $post->course)) { // For the logs
+        if (!$cm = get_coursemodule_from_instance("forum", $post->forum, $course->id)) { // For the logs
             $cm->id = 0;
         }
 
@@ -38,7 +48,7 @@
             $post->id = $post->edit;
             if (forum_update_post($post)) {
 
-                add_to_log($post->course, "forum", "update post", 
+                add_to_log($course->id, "forum", "update post", 
                           "discuss.php?d=$post->discussion&parent=$post->id", "$post->id", $cm->id);
 
                 $message = get_string("postupdated", "forum");
@@ -57,7 +67,7 @@
         } else if ($post->discussion) { // Adding a new post to an existing discussion
             if ($post->id = forum_add_new_post($post)) {
 
-                add_to_log($post->course, "forum", "add post", 
+                add_to_log($course->id, "forum", "add post", 
                           "discuss.php?d=$post->discussion&parent=$post->id", "$post->id", $cm->id);
 
                 $message = get_string("postadded", "forum", format_time($CFG->maxeditingtime));
@@ -80,7 +90,7 @@
             $discussion->intro = $post->message;
             if ($discussion->id = forum_add_discussion($discussion)) {
 
-                add_to_log($post->course, "forum", "add discussion", 
+                add_to_log($course->id, "forum", "add discussion", 
                            "discuss.php?d=$discussion->id", "$discussion->id", $cm->id);
 
                 $message = get_string("postadded", "forum", format_time($CFG->maxeditingtime));
@@ -105,6 +115,8 @@
         $defaultformat = FORMAT_MOODLE;
     }
 
+    $parent=NULL;  // Initialise some things
+
 
     if (isset($post->error)) {     // User is re-editing a failed posting
 
@@ -159,19 +171,23 @@
         $post->parent = 0;
         $post->subject = "";
         $post->userid = $USER->id;
-        $post->groupid = get_current_group($course->id);
         $post->message = "";
         $post->format = $defaultformat;
 
+        $post->groupid = get_current_group($course->id);
+        if (isteacheredit($course->id) and $post->groupid == 0) {
+            $post->groupid = -1;
+        }
+
         forum_set_return();
 
     } else if (isset($reply)) {      // User is writing a new reply
 
         if (! $parent = forum_get_post_full($reply)) {
-            error("Parent post ID was incorrect ($reply)");
+            error("Parent post ID was incorrect");
         }
         if (! $discussion = get_record("forum_discussions", "id", $parent->discussion)) {
-            error("This post is not part of a discussion! ($reply)");
+            error("This post is not part of a discussion!");
         }
         if (! $forum = get_record("forum", "id", $discussion->forum)) {
             error("The forum number was incorrect ($discussion->forum)");
@@ -265,6 +281,13 @@
         if (($post->userid <> $USER->id) and !isteacher($forum->course)) {
             error("You can't delete other people's posts!");
         }
+        if (!empty($forum->course)) {
+            if ($course = get_record('course', 'id', $forum->course)) {
+                if (!empty($course->lang)) {
+                    $CFG->courselang = $course->lang;
+                }
+            }
+        }
 
         if (isset($confirm)) {    // User has confirmed the delete
 
@@ -322,6 +345,89 @@
         die;
 
 
+    } else if (isset($prune)) {  // Teacher is pruning
+        
+        if (! $post = forum_get_post_full($prune)) {
+            error("Post ID was incorrect");
+        }
+        if (! $discussion = get_record("forum_discussions", "id", $post->discussion)) {
+            error("This post is not part of a discussion!");
+        }
+        if (! $forum = get_record("forum", "id", $discussion->forum)) {
+            error("The forum number was incorrect ($discussion->forum)");
+        }
+        if (!isteacher($forum->course)) {
+            error("You can't split discussions!");
+        }
+        if (!$post->parent) {
+            error('This is already the first post in the discussion');
+        }
+
+        if (isset($_REQUEST['name'])) {    // User has confirmed the prune
+            
+            $newdiscussion->course = $discussion->course;
+            $newdiscussion->forum = $discussion->forum;
+            $newdiscussion->name = $name;
+            $newdiscussion->firstpost = $post->id;
+            $newdiscussion->userid = $discussion->userid;
+            $newdiscussion->groupid = $discussion->groupid;
+            $newdiscussion->assessed = $discussion->assessed;
+            $newdiscussion->usermodified = $post->userid;
+            
+            if (!$newid = insert_record('forum_discussions', $newdiscussion)) {
+                error('Could not create new discussion');
+            }
+            
+            $newpost->id = $post->id;
+            $newpost->parent = 0;
+            $newpost->subject = $name;
+
+            if (!update_record("forum_posts", $newpost)) {
+                error('Could not update the original post');
+            }
+
+            forum_change_discussionid($post->id, $newid);
+            
+            // set timemodified to time of last post in each discussion
+            $lastpost = get_record_sql("SELECT MAX(modified) AS time
+                                              FROM {$CFG->prefix}forum_posts 
+                                              WHERE discussion = '$discussion->id'");
+            set_field('forum_discussions', 'timemodified', $lastpost->time, 'id', $discussion->id);
+            $lastpost = get_record_sql("SELECT MAX(modified) AS time
+                                              FROM {$CFG->prefix}forum_posts 
+                                              WHERE discussion = '$newid'");
+            set_field('forum_discussions', 'timemodified', $lastpost->time, 'id', $newid);            
+
+
+            if (!$cm = get_coursemodule_from_instance("forum", $forum->id, $forum->course)) { // For the logs
+                $cm->id = 0;
+            }
+            add_to_log($discussion->course, "forum", "prune post", 
+                           "discuss.php?d=$newid", "$post->id", $cm->id);
+
+            redirect(forum_go_back_to("discuss.php?d=$newid"), get_string("prunedpost", "forum"), 1);
+
+        } else { // User just asked to prune something
+
+            $course = get_record('course', 'id', $forum->course);
+            $strforums = get_string("modulenameplural", "forum");
+            print_header_simple("$discussion->name: $post->subject", "",
+                         "<a href=\"../forum/index.php?id=$course->id\">$strforums</a> -> 
+                          <a href=\"view.php?f=$forum->id\">$forum->name</a> -> 
+                          <a href=\"discuss.php?d=$discussion->id\">$post->subject</a> -> ".
+                          get_string("prune", "forum"), '', "", true, "", navmenu($course, $cm));
+            
+            print_heading(get_string('pruneheading', 'forum'));
+            echo '<center>';
+            
+            include('prune.html');
+                         
+            forum_print_post($post, $forum->course, $ownpost=false, $reply=false, $link=false);
+        }
+
+        die;
+
+
     } else {
         error("No operation specified");
 
