@@ -1,4 +1,4 @@
-<?PHP  // $Id: lib.php,v 1.82 2004/05/21 18:56:21 stronk7 Exp $
+<?PHP  // $Id: lib.php,v 1.89.2.18 2005/02/18 01:15:15 stronk7 Exp $
 
 /// Library of functions and constants for module glossary
 /// (replace glossary with the name of your module and delete this line)
@@ -18,8 +18,33 @@ define("GLOSSARY_IMPORT_VIEW", 5);
 define("GLOSSARY_EXPORT_VIEW", 6);
 define("GLOSSARY_APPROVAL_VIEW", 7);
 
-define("GLOSSARY_FORMAT_SIMPLE", 0);
-define("GLOSSARY_FORMAT_CONTINUOUS", 1);
+//Check for global configure default variables
+
+if (!isset($CFG->glossary_studentspost)) {
+    set_config("glossary_studentspost", 1);  // Students can post entries.
+}
+
+if (!isset($CFG->glossary_dupentries)) {
+    set_config("glossary_dupentries", 0);  // Duplicate entries are not allowed.
+}
+
+if (!isset($CFG->glossary_allowcomments)) {
+    set_config("glossary_allowcomments", 0);  // Comments are not allowed.
+}
+
+if (!isset($CFG->glossary_linkbydefault)) {
+    set_config("glossary_linkbydefault", 1);  // Linking entries is enabled.
+}
+
+if (!isset($CFG->glossary_defaultapproval)) {
+    set_config("glossary_defaultapproval", 1);  // Entries are approved.
+}
+
+if (!isset($CFG->glossary_entbypage)) {
+    set_config("glossary_entbypage", 10);  // 10 entries are showed.
+}
+
+/// STANDARD FUNCTIONS ///////////////////////////////////////////////////////////
 
 function glossary_add_instance($glossary) {
 /// Given an object containing all the necessary data,
@@ -27,7 +52,7 @@ function glossary_add_instance($glossary) {
 /// will create a new instance and return the id number
 /// of the new instance.
 
-    if (!$glossary->userating) {
+    if (!isset($glossary->userating) || !$glossary->userating) {
         $glossary->assessed = 0;
     }
 
@@ -50,7 +75,11 @@ function glossary_add_instance($glossary) {
     $glossary->timecreated = time();
     $glossary->timemodified = $glossary->timecreated;
 
-    # May have to add extra stuff in here #
+    //Check displayformat is a valid one
+    $formats = get_list_of_plugins('mod/glossary/formats','TEMPLATE');
+    if (!in_array($glossary->displayformat, $formats)) {
+        error("This format doesn't exist!");
+    }  
 
     return insert_record("glossary", $glossary);
 }
@@ -64,11 +93,14 @@ global $CFG;
     if ( !isadmin() ) {
         unset($glossary->globalglossary);
     }
+    if (empty($glossary->globalglossary)) {
+        $glossary->globalglossary = 0;
+    }
 
     $glossary->timemodified = time();
     $glossary->id = $glossary->instance;
 
-    if (!$glossary->userating) {
+    if (!isset($glossary->userating) || !$glossary->userating) {
         $glossary->assessed = 0;
     }
 
@@ -82,6 +114,12 @@ global $CFG;
         $glossary->assesstimefinish = 0;
     }
 
+    //Check displayformat is a valid one
+    $formats = get_list_of_plugins('mod/glossary/formats','TEMPLATE');
+    if (!in_array($glossary->displayformat, $formats)) {
+        error("This format doesn't exist!");
+    }
+
     $return = update_record("glossary", $glossary);
 	if ($return and $glossary->defaultapproval) {
         execute_sql("update {$CFG->prefix}glossary_entries SET approved = 1 where approved != 1 and glossaryid = " . $glossary->id,false);
@@ -109,7 +147,7 @@ function glossary_delete_instance($id) {
     } else {
         if ($categories = get_records("glossary_categories","glossaryid",$glossary->id)) {
             $cats = "";
-            foreach ( $categories as $hook ) {
+            foreach ( $categories as $cat ) {
                 $cats .= "$cat->id,";
             }
             $cats = substr($cats,0,-1);
@@ -181,23 +219,13 @@ function glossary_user_complete($course, $user, $mod, $glossary) {
     global $CFG;
 
     if ($entries = glossary_get_user_entries($glossary->id, $user->id)) {
-        if ( $glossary->displayformat == GLOSSARY_FORMAT_SIMPLE or
-             $glossary->displayformat == GLOSSARY_FORMAT_CONTINUOUS ) {
-            print_simple_box_start("center","70%");
-        } else {
-            echo '<table width="95%" border="0"><tr><td>';
-        }
+        echo '<table width="95%" border="0"><tr><td>';
         foreach ($entries as $entry) {
             $cm = get_coursemodule_from_instance("glossary", $glossary->id, $course->id);
             glossary_print_entry($course, $cm, $glossary, $entry,"","",0);
             echo '<p>';
         }
-        if ( $glossary->displayformat == GLOSSARY_FORMAT_SIMPLE or
-             $glossary->displayformat == GLOSSARY_FORMAT_CONTINUOUS ) {
-            print_simple_box_end();
-        } else {
-            echo '</td></tr></table>';
-        }
+        echo '</td></tr></table>';
     }
 }
 
@@ -216,6 +244,8 @@ function glossary_print_recent_activity($course, $isteacher, $timestart) {
         return false;
     }
 
+    $entries = array();
+
     foreach ($logs as $log) {
         //Create a temp valid module structure (course,id)
         $tempmod->course = $log->course;        
@@ -380,6 +410,64 @@ function glossary_scale_used ($glossaryid,$scaleid) {
 /// Any other glossary functions go here.  Each of them must have a name that
 /// starts with glossary_
 
+//This function return an array of valid glossary_formats records
+//Everytime it's called, every existing format is checked, new formats
+//are included if detected and old formats are deleted and any glossary
+//using an invalid format is updated to the default (dictionary).
+function glossary_get_available_formats() {
+
+    global $CFG;
+
+    //Get available formats (plugin) and insert (if necessary) them into glossary_formats
+    $formats = get_list_of_plugins('mod/glossary/formats', 'TEMPLATE');
+    $pluginformats = array();
+    foreach ($formats as $format) {
+        //If the format file exists
+        if (file_exists($CFG->dirroot.'/mod/glossary/formats/'.$format.'/'.$format.'_format.php')) {
+            include_once($CFG->dirroot.'/mod/glossary/formats/'.$format.'/'.$format.'_format.php');
+            //If the function exists
+            if (function_exists('glossary_show_entry_'.$format)) {
+                //Acummulate it as a valid format
+                $pluginformats[] = $format;
+                //If the format doesn't exist in the table
+                if (!$rec = get_record('glossary_formats','name',$format)) {
+                    //Insert the record in glossary_formats
+                    $gf->name = $format;
+                    $gf->popupformatname = $format;
+                    $gf->visible = 1;
+                    insert_record("glossary_formats",$gf);
+                }
+            }
+        }
+    }
+
+    //Delete non_existent formats from glossary_formats table
+    $formats = get_records("glossary_formats");
+    foreach ($formats as $format) {
+        $todelete = false;
+        //If the format in DB isn't a valid previously detected format then delete the record
+        if (!in_array($format->name,$pluginformats)) {
+            $todelete = true;
+        }
+
+        if ($todelete) {
+            //Delete the format
+            delete_records('glossary_formats','name',$format->name);
+            //Reasign existing glossaries to default (dictionary) format
+            if ($glossaries = get_records('glossary','displayformat',$format->name)) {
+                foreach($glossaries as $glossary) {
+                    set_field('glossary','displayformat','dictionary','id',$glossary->id);
+                }
+            }
+        }
+    }
+
+    //Now everything is ready in glossary_formats table
+    $formats = get_records("glossary_formats");
+
+    return $formats;
+}
+
 function glossary_debug($debug,$text,$br=1) {
     if ( $debug ) {
         echo '<font color=red>' . $text . '</font>';
@@ -400,6 +488,23 @@ function glossary_get_entries($glossaryid, $entrylist, $pivot = "") {
                             WHERE glossaryid = '$glossaryid'
                             AND id IN ($entrylist)");
 }
+
+function glossary_get_entries_search($concept, $courseid) {
+    global $CFG;
+
+    $conceptupper = strtoupper(trim($concept));
+
+    return get_records_sql("SELECT e.*, g.name as glossaryname
+                              FROM {$CFG->prefix}glossary_entries e, 
+                                   {$CFG->prefix}glossary g
+                             WHERE e.glossaryid = g.id 
+                               AND (    (e.casesensitive != 0 and UPPER(concept) = '$conceptupper')
+                                     OR (e.casesensitive = 0 and concept = '$concept'))
+                               AND (g.course = '$courseid' OR g.globalglossary = 1)
+                               AND e.usedynalink != 0 
+                               AND g.usedynalink != 0");
+}
+
 function glossary_get_entries_sorted($glossary, $where="", $orderby="", $pivot = "") {
 global $CFG;
     if ($where) {
@@ -433,45 +538,41 @@ global $CFG;
                                              (ge.glossaryid = $glossary->id or ge.sourceglossaryid = $glossary->id) $where $orderby");
 }
 
-function glossary_print_entry($course, $cm, $glossary, $entry, $mode="",$hook="",$printicons = 1, $displayformat  = -1, $ratings = NULL) {
+function glossary_print_entry($course, $cm, $glossary, $entry, $mode="",$hook="",$printicons = 1, $displayformat  = -1, $ratings = NULL, $printview = false) {
     global $THEME, $USER, $CFG;
     $return = false;
     if ( $displayformat < 0 ) {
         $displayformat = $glossary->displayformat;
     }
     if ($entry->approved or ($USER->id == $entry->userid) or ($mode == 'approval' and !$entry->approved) ) {
-        $permissiongranted = 0;
-        $formatfile = "$CFG->dirroot/mod/glossary/formats/$displayformat.php";
-        $functionname = "glossary_print_entry_by_format";
-
-        $basicformat = ($displayformat == GLOSSARY_FORMAT_SIMPLE or
-                        $displayformat == GLOSSARY_FORMAT_CONTINUOUS);
-        if ( !$basicformat ) {
-            if ( file_exists($formatfile) ) {
-               include_once($formatfile);
-               if (function_exists($functionname) ) {
-                      $permissiongranted = 1;
-               }
-            }
+        $formatfile = $CFG->dirroot.'/mod/glossary/formats/'.$displayformat.'/'.$displayformat.'_format.php';
+        if ($printview) {
+            $functionname = 'glossary_print_entry_'.$displayformat;
         } else {
-           $permissiongranted = 1;
+            $functionname = 'glossary_show_entry_'.$displayformat;
         }
-    
-        if ( !$basicformat and $permissiongranted or $displayformat >= 2) {
-            $return = glossary_print_entry_by_format($course, $cm, $glossary, $entry,$mode,$hook,$printicons,$ratings);
-        } else {
-            switch ( $displayformat ) {
-            case GLOSSARY_FORMAT_SIMPLE:
-                $return = glossary_print_entry_by_default($course, $cm, $glossary, $entry,$mode,$hook,$printicons,$ratings);
-            break;
-            case GLOSSARY_FORMAT_CONTINUOUS:
-                $return = glossary_print_entry_continuous($course, $cm, $glossary, $entry,$mode,$hook,$printicons,$ratings);
-            break;
+
+        if (file_exists($formatfile)) {
+            include_once($formatfile);
+            if (function_exists($functionname)) {
+                $return = $functionname($course, $cm, $glossary, $entry,$mode,$hook,$printicons,$ratings);
+            } else if ($printview) {
+                //If the glossary_print_entry_XXXX function doesn't exist, print default (old) print format
+                $return = glossary_print_entry_default($entry);
             }
         }
     }
-        return $return;
+    return $return;
 }
+ //Default (old) print format used if custom function doesn't exist in format
+function glossary_print_entry_default ($entry) {
+    echo '<b>'. strip_tags($entry->concept) . ': </b>';
+    $options->para = false;
+    $definition = format_text('<nolink>' . strip_tags($entry->definition) . '</nolink>', $entry->format,$options);
+    echo ($definition);
+    echo '<br /><br />';
+}
+
 function  glossary_print_entry_concept($entry) {
     $options->para = false;
     $text = format_text('<nolink>' . $entry->concept . '</nolink>', FORMAT_MOODLE, $options);
@@ -486,6 +587,8 @@ function glossary_print_entry_definition($entry) {
     $definition = $entry->definition;
 
     $tags = array();
+    $urls = array();
+    $addrs = array();
 
     //Calculate all the strings to be no-linked
     //First, the concept
@@ -513,10 +616,46 @@ function glossary_print_entry_definition($entry) {
     if ( $tags ) {
         $definition = str_replace($tags,array_keys($tags),$definition);
     }
-    
+
+    //Extract all URLS with protocol (http://domain.com) from definition
+    preg_match_all('/([[:space:]]|^|\(|\[)([[:alnum:]]+):\/\/([^[:space:]]*)([[:alnum:]#?\/&=])/is',$definition,$list_of_urls);
+
+    //Save them into urls array to use them later
+    foreach (array_unique($list_of_urls[0]) as $key=>$value) {
+        $urls['<*'.$key.'*>'] = $value;
+    }
+
+    //Take off every url from definition
+    if ( $urls ) {
+        $definition = str_replace($urls,array_keys($urls),$definition);
+    }
+
+    //Extract all WEB ADDRESSES (www.domain.com) from definition
+    preg_match_all('/([[:space:]]|^|\(|\[)www\.([^[:space:]]*)([[:alnum:]#?\/&=])/is',$definition,$list_of_addresses);
+
+    //Save them into addrs array to use them later
+    foreach (array_unique($list_of_addresses[0]) as $key=>$value) {
+        $addrs['<+'.$key.'+>'] = $value;
+    }
+
+    //Take off every addr from definition
+    if ( $addrs ) {
+        $definition = str_replace($addrs,array_keys($addrs),$definition);
+    }
+
     //Put doNolinks (concept + aliases) enclosed by <nolink> tag
     $definition= preg_replace($doNolinks,'<nolink>$1</nolink>',$definition);
         
+    //Restore addrs
+    if ( $addrs ) {
+        $definition = str_replace(array_keys($addrs),$addrs,$definition);
+    }
+
+    //Restore urls
+    if ( $urls ) {
+        $definition = str_replace(array_keys($urls),$urls,$definition);
+    }
+
     //Restore tags
     if ( $tags ) {
         $definition = str_replace(array_keys($tags),$tags,$definition);
@@ -527,6 +666,9 @@ function glossary_print_entry_definition($entry) {
     if (!empty($entry->highlight)) {
         $text = highlight($entry->highlight, $text);
     }
+    if (isset($entry->footer)) {   // Unparsed footer info
+        $text .= $entry->footer;
+    }
     echo $text;
 }
 
@@ -543,7 +685,6 @@ function  glossary_print_entry_aliases($course, $cm, $glossary, $entry,$mode="",
         }
         if ($return != '') {
             $return .= '</select>';
-//            $return = "<table border=0 align=$align><tr><td>$return</td></tr></table>";
         }
     } 
     if ($type == 'print') {
@@ -556,12 +697,14 @@ function  glossary_print_entry_aliases($course, $cm, $glossary, $entry,$mode="",
 function glossary_print_entry_icons($course, $cm, $glossary, $entry,$mode="",$hook="", $type = 'print') {
     global $THEME, $USER, $CFG;
 
+    $output = false;   //To decide if we must really return text in "return". Activate when needed only!
     $importedentry = ($entry->sourceglossaryid == $glossary->id);
     $isteacher = isteacher($course->id);
     $ismainglossary = $glossary->mainglossary;
 	
     $return = "<font size=1>";
     if (!$entry->approved) {
+        $output = true;
         $return .= get_string("entryishidden","glossary");
     }
     $return .= glossary_print_entry_commentslink($course, $cm, $glossary, $entry,$mode,$hook,'html');
@@ -569,16 +712,17 @@ function glossary_print_entry_icons($course, $cm, $glossary, $entry,$mode="",$ho
     $return .= "</font> ";
 
     
-    if ( $glossary->allowcomments and !isguest()) {
+    if ( (!empty($USER->id) && $glossary->allowcomments && !isguest()) || $isteacher) {
+        $output = true;
         $return .= " <a title=\"" . get_string("addcomment","glossary") . "\" href=\"comment.php?id=$cm->id&eid=$entry->id\"><img src=\"comment.gif\" height=11 width=11 border=0></a> ";
     }
 
-    if ($isteacher or $glossary->studentcanpost and $entry->userid == $USER->id) {
+    if ($isteacher or (!empty($USER->id) and $glossary->studentcanpost and $entry->userid == $USER->id)) {
         // only teachers can export entries so check it out
         if ($isteacher and !$ismainglossary and !$importedentry) {
             $mainglossary = get_record("glossary","mainglossary",1,"course",$course->id);
             if ( $mainglossary ) {  // if there is a main glossary defined, allow to export the current entry
-
+                $output = true;
                 $return .= " <a title=\"" . get_string("exporttomainglossary","glossary") . "\" href=\"exportentry.php?id=$cm->id&entry=$entry->id&mode=$mode&hook=$hook\"><img src=\"export.gif\" height=11 width=11 border=0></a> ";
 
             }
@@ -590,8 +734,12 @@ function glossary_print_entry_icons($course, $cm, $glossary, $entry,$mode="",$ho
             $icon = "$CFG->pixpath/t/delete.gif";
         }
 
-        // Exported entries can be updated/deleted only by teachers in the main glossary
-        if ( !$importedentry and ($isteacher or !$ismainglossary) ) {
+        //Decide if an entry is editable:
+        // -It isn't a imported entry (so nobody can edit a imported (from secondary to main) entry)) and
+        // -The user is teacher or he is a student with time permissions (edit period or editalways defined).
+        $ineditperiod = ((time() - $entry->timecreated <  $CFG->maxeditingtime) || $glossary->editalways);
+        if ( !$importedentry and ($isteacher or ($entry->userid == $USER->id and $ineditperiod))) {
+            $output = true;
             $return .= " <a title=\"" . get_string("delete") . "\" href=\"deleteentry.php?id=$cm->id&mode=delete&entry=$entry->id&prevmode=$mode&hook=$hook\"><img src=\"";
             $return .= $icon;
             $return .= "\" height=11 width=11 border=0></a> ";
@@ -602,6 +750,12 @@ function glossary_print_entry_icons($course, $cm, $glossary, $entry,$mode="",$ho
         }
     }
     $return .= "&nbsp;&nbsp;"; // just to make up a little the output in Mozilla ;)
+
+    //If we haven't calculated any REAL thing, delete result ($return)
+    if (!$output) {
+        $return = '';
+    }
+    //Print or get
     if ($type == 'print') {
         echo $return;
     } else {
@@ -632,91 +786,62 @@ function glossary_print_entry_commentslink($course, $cm, $glossary, $entry,$mode
     }
 }
 
-function  glossary_print_entry_lower_section($course, $cm, $glossary, $entry, $mode, $hook,$printicons) {
+function  glossary_print_entry_lower_section($course, $cm, $glossary, $entry, $mode, $hook,$printicons,$ratings,$aliases=true) {
 
-    $aliases = glossary_print_entry_aliases($course, $cm, $glossary, $entry, $mode, $hook,"html");
+    if ($aliases) {
+        $aliases = glossary_print_entry_aliases($course, $cm, $glossary, $entry, $mode, $hook,"html");
+    }
     $icons   = "";
+    $return   = "";
     if ( $printicons ) {
         $icons   = glossary_print_entry_icons($course, $cm, $glossary, $entry, $mode, $hook,"html");
     }
-    if ( $aliases ) {
-        echo '<table border="0" width="100%" align="center"><tr>' .
-              '<td align="right" width="50%" valign=top><font size=1>' .
-              get_string("aliases","glossary") . ': ' . $aliases . '</td>' .
-              '<td align=right width="50%" valign=top>'.
-              $icons .
-              '</td></tr></table>';
-    } else {
-        echo "<p align=right>$icons";
+    if ($aliases || $icons || $ratings) {
+        echo '<table border="0" width="100%" align="center">';
+        if ( $aliases ) {
+            echo '<tr><td align="center"  valign="top"><font size=1>' .
+                  get_string("aliases","glossary") . ': ' . $aliases . '</td></tr>';
+        }
+        if ($icons) {
+            echo '<tr><td align=right valign=top>'.  $icons . '</td></tr>';
+        }
+        if ($ratings) {
+            echo '<tr><td align=right valign=top>';
+            $return = glossary_print_entry_ratings($course, $entry, $ratings);
+            echo '</td></tr>';
+        }
+        echo '</table>';
     }
+    return $return;
 }
 
-function glossary_print_entry_attachment($entry,$format=NULL,$align="right") {
+function glossary_print_entry_attachment($entry,$format=NULL,$align="right",$insidetable=true) {
 ///   valid format values: html  : Return the HTML link for the attachment as an icon
 ///                        text  : Return the HTML link for tha attachment as text
 ///                        blank : Print the output to the screen
     if ($entry->attachment) {
           $glossary = get_record("glossary","id",$entry->glossaryid);		  
           $entry->course = $glossary->course; //used inside print_attachment
-          echo "<table border=0 align=$align><tr><td>";
+          if ($insidetable) {
+              echo "<table border=\"0\" width=\"100%\" align=\"$align\"><tr><td align=\"$align\" nowrap>\n";
+          }
           echo glossary_print_attachments($entry,$format,$align);
-          echo "</td></tr></table>";
+          if ($insidetable) {
+              echo "</td></tr></table>\n";
+          }
     }
 }
 
-function  glossary_print_entry_approval($cm, $entry, $mode) {
+function  glossary_print_entry_approval($cm, $entry, $mode,$align="right",$insidetable=true) {
     if ( $mode == 'approval' and !$entry->approved ) {
-        echo "<a title=\"" . get_string("approve","glossary"). "\" href=\"approve.php?id=$cm->id&eid=$entry->id&mode=$mode\"><IMG align=\"right\" src=\"check.gif\" border=0 width=\"34\" height=\"34\"></a>";
-    }
-}
-
-function glossary_print_entry_by_default($course, $cm, $glossary, $entry,$mode="",$hook="",$printicons=1, $ratings=NULL) {
-    global $THEME, $USER;
-
-    $colour = $THEME->cellheading2;
-
-    echo "\n<TR>";
-    echo "<TD WIDTH=100% valign=\"top\" BGCOLOR=\"#FFFFFF\">";
-        glossary_print_entry_approval($cm, $entry, $mode);
-        glossary_print_entry_attachment($entry,"html","right");
-        echo "<b>";
-        glossary_print_entry_concept($entry);
-        echo ":</b> ";
-        glossary_print_entry_definition($entry);
-        glossary_print_entry_lower_section($course, $cm, $glossary, $entry,$mode,$hook,$printicons);
-        echo ' ';
-        $return = glossary_print_entry_ratings($course, $entry, $ratings);
-    echo "</td>";
-    echo "</TR>";
-    return $return;
-}
-
-function glossary_print_entry_continuous($course, $cm, $glossary, $entry,$mode="",$hook="",$printicons=1, $ratings = NULL) {
-    global $THEME, $USER;
-    $return = false;
-    if ($entry) {
-        glossary_print_entry_approval($cm, $entry, $mode);
-        glossary_print_entry_attachment($entry,"html","right");
-        glossary_print_entry_concept($entry);
-        echo " ";
-        
-        glossary_print_entry_definition($entry);
-        
-        $icons = '';
-        if ( $printicons ) {
-            $icons = glossary_print_entry_icons($course, $cm, $glossary, $entry, $mode, $hook,"html");        
-        }        
-
-        echo '(';
-        if ( $icons ) {
-            echo $icons;
+        if ($insidetable) {
+            echo "<table border=\"0\" width=\"100%\" align=\"$align\"><tr><td align=\"$align\">\n";
+        }
+        echo "<a title=\"" . get_string("approve","glossary"). "\" href=\"approve.php?id=$cm->id&eid=$entry->id&mode=$mode\"><img align=\"$align\" src=\"check.gif\" border=0 width=\"34\" height=\"34\"></a>\n";
+        if ($insidetable) {
+            echo "</td></tr></table>\n";
         }
-        $return = glossary_print_entry_ratings($course, $entry, $ratings);
-        
-        echo ')<br>';
-
     }
-    return $return;
 }
 
 function glossary_search($course, $searchterms, $extended = 0, $glossary = NULL) {
@@ -1014,7 +1139,7 @@ function glossary_print_attachments($entry, $return=NULL, $align="left") {
 
                 } else {
                     if ($icon == "image.gif") {    // Image attachments don't get printed as links
-                        $imagereturn .= "<br /><img src=\"$CFG->wwwroot/$ffurl\" align=$align>";
+                        $imagereturn .= "<img src=\"$CFG->wwwroot/$ffurl\" align=\"$align\">";
                     } else {
                         link_to_popup_window("/$ffurl", "attachment", $image, 500, 500, $strattachment);
                         echo "<a target=_image href=\"$CFG->wwwroot/$ffurl\">$file</a>";
@@ -1184,7 +1309,7 @@ function glossary_print_tabbed_table_end() {
 }
 
 function glossary_print_approval_menu($cm, $glossary,$mode, $hook, $sortkey = '', $sortorder = '') {
-    if ($glossary->showalphabet and $glossary->displayformat != GLOSSARY_FORMAT_CONTINUOUS) {
+    if ($glossary->showalphabet) {
         echo '<center>' . get_string("explainalphabet","glossary") . '<p>';
     }
     glossary_print_special_links($cm, $glossary, $mode, $hook);
@@ -1210,7 +1335,7 @@ function glossary_print_export_menu($cm, $glossary, $mode, $hook, $sortkey='', $
 
 function glossary_print_alphabet_menu($cm, $glossary, $mode, $hook, $sortkey='', $sortorder = '') {
     if ( $mode != 'date' ) {
-        if ($glossary->showalphabet and $glossary->displayformat != GLOSSARY_FORMAT_CONTINUOUS) {
+        if ($glossary->showalphabet) {
             echo '<center>' . get_string("explainalphabet","glossary") . '<p>';
         }
 
@@ -1225,7 +1350,7 @@ function glossary_print_alphabet_menu($cm, $glossary, $mode, $hook, $sortkey='',
 }
 
 function glossary_print_author_menu($cm, $glossary,$mode, $hook, $sortkey = '', $sortorder = '') {
-    if ($glossary->showalphabet and $glossary->displayformat != GLOSSARY_FORMAT_CONTINUOUS) {
+    if ($glossary->showalphabet) {
         echo '<center>' . get_string("explainalphabet","glossary") . '<br />';
     }
 
@@ -1265,7 +1390,7 @@ global $CFG, $THEME;
                          $selected = $url;
                      }
                  }
-                 $menu[$url] = $currentcategory->name;
+                 $menu[$url] = clean_text($currentcategory->name); //Only clean, not filters
           }
      }
      if ( !$selected ) {
@@ -1273,7 +1398,7 @@ global $CFG, $THEME;
      }
 
      if ( $category ) {
-        echo $category->name;
+        echo format_text($category->name);
      } else {
         if ( $hook == GLOSSARY_SHOW_NOT_CATEGORISED ) {
 
@@ -1301,7 +1426,7 @@ global $CFG, $THEME;
 
 function glossary_print_all_links($cm, $glossary, $mode, $hook) {
 global $CFG;  
-     if ( $glossary->showall and $glossary->displayformat != GLOSSARY_FORMAT_CONTINUOUS) {
+     if ( $glossary->showall) {
          $strallentries       = get_string("allentries", "glossary");
          if ( $hook == 'ALL' ) {
               echo "<b>$strallentries</b>";
@@ -1314,7 +1439,7 @@ global $CFG;
 
 function glossary_print_special_links($cm, $glossary, $mode, $hook) {
 global $CFG;
-     if ( $glossary->showspecial and $glossary->displayformat != GLOSSARY_FORMAT_CONTINUOUS ) {
+     if ( $glossary->showspecial) {
          $strspecial          = get_string("special", "glossary");
          if ( $hook == 'SPECIAL' ) {
               echo "<b>$strspecial</b> | ";
@@ -1327,7 +1452,7 @@ global $CFG;
 
 function glossary_print_alphabet_links($cm, $glossary, $mode, $hook, $sortkey, $sortorder) {
 global $CFG;
-     if ( $glossary->showalphabet and $glossary->displayformat != GLOSSARY_FORMAT_CONTINUOUS ) {
+     if ( $glossary->showalphabet) {
           $alphabet = explode(",", get_string("alphabet"));
           $letters_by_line = 14;
           for ($i = 0; $i < count($alphabet); $i++) {
@@ -1465,11 +1590,12 @@ function glossary_print_comment($course, $cm, $glossary, $entry, $comment) {
     echo format_text($comment->comment, $comment->format);
 
     echo "<div align=right><p align=right>";
-    if ( (time() - $comment->timemodified <  $CFG->maxeditingtime and $USER->id == $comment->userid)  or isteacher($course->id) ) {
+    $ineditperiod = ((time() - $comment->timemodified <  $CFG->maxeditingtime) || $glossary->editalways);
+    if ( ($glossary->allowcomments &&  $ineditperiod && $USER->id == $comment->userid)  || isteacher($course->id) ) {
         echo "<a href=\"comment.php?id=$cm->id&eid=$entry->id&cid=$comment->id&action=edit\"><img  
                alt=\"" . get_string("edit") . "\" src=\"$CFG->pixpath/t/edit.gif\" height=11 width=11 border=0></a> ";
     }
-    if ( $USER->id == $comment->userid or isteacher($course->id) ) {
+    if ( ($glossary->allowcomments && $USER->id == $comment->userid) || isteacher($course->id) ) {
         echo "<a href=\"comment.php?id=$cm->id&eid=$entry->id&cid=$comment->id&action=delete\"><img  
                alt=\"" . get_string("delete") . "\" src=\"$CFG->pixpath/t/delete.gif\" height=11 width=11 border=0></a>";
     }
@@ -1481,7 +1607,9 @@ function glossary_print_comment($course, $cm, $glossary, $entry, $comment) {
 }
 
 function  glossary_print_entry_ratings($course, $entry, $ratings = NULL) {
-global $USER;
+    
+    global $USER;
+
     $ratingsmenuused = false;
     if (!empty($ratings) and !empty($USER->id)) {
         $useratings = true;
@@ -1509,7 +1637,7 @@ global $USER;
 }
 
 function glossary_print_dynaentry($courseid, $entries, $displayformat = -1) {
-    global $THEME, $USER;
+    global $THEME, $USER,$CFG;
 
     $colour = $THEME->cellheading2;
 
@@ -1526,14 +1654,32 @@ function glossary_print_dynaentry($courseid, $entries, $displayformat = -1) {
             if (!$cm = get_coursemodule_from_instance("glossary", $entry->glossaryid, $glossary->course) ) {
                 error("Glossary is misconfigured - don't know what course module it is ");
             }
-            $dp = $displayformat;
-            // Hard-coded until the Display formats manager is done.
-            if ( $dprecord = get_record("glossary_displayformats","fid", $glossary->displayformat) ) {
-                if ( $dprecord->relatedview >= 0 ) {
-                    $dp = $dprecord->relatedview;
+
+            //If displayformat is present, override glossary->displayformat
+            if ($displayformat < 0) {
+                $dp = $glossary->displayformat;
+            } else {
+                $dp = $displayformat;
+            }
+
+            //Get popupformatname
+            $format = get_record('glossary_formats','name',$dp);
+            $displayformat = $format->popupformatname;
+
+            //Check displayformat variable and set to default if necessary
+            if (!$displayformat) {
+                $displayformat = 'dictionary';
+            }
+
+            $formatfile = $CFG->dirroot.'/mod/glossary/formats/'.$displayformat.'/'.$displayformat.'_format.php';
+            $functionname = 'glossary_show_entry_'.$displayformat;
+
+            if (file_exists($formatfile)) {
+                include_once($formatfile);
+                if (function_exists($functionname)) {
+                    $functionname($course, $cm, $glossary, $entry,'','','','');
                 }
             }
-            glossary_print_entry($course, $cm, $glossary, $entry, "","",0,$dp);
         }
     }
     echo "</td>";
@@ -1553,6 +1699,7 @@ global $CFG;
         fwrite ($h,glossary_full_tag("INTRO",2,false,$glossary->intro));
         fwrite ($h,glossary_full_tag("STUDENTCANPOST",2,false,$glossary->studentcanpost));
         fwrite ($h,glossary_full_tag("ALLOWDUPLICATEDENTRIES",2,false,$glossary->allowduplicatedentries));
+        fwrite ($h,glossary_full_tag("DISPLAYFORMAT",2,false,$glossary->displayformat));
         fwrite ($h,glossary_full_tag("SHOWSPECIAL",2,false,$glossary->showspecial));
         fwrite ($h,glossary_full_tag("SHOWALPHABET",2,false,$glossary->showalphabet));
         fwrite ($h,glossary_full_tag("SHOWALL",2,false,$glossary->showall));
@@ -1675,7 +1822,7 @@ require_once "../../lib/xmlize.php";
         }
         fclose($h);
 	}
-    return xmlize($line);
+    return xmlize($line, 0);
 }
 //Close the file
 function glossary_close_xml($h) {
@@ -1910,14 +2057,152 @@ function glossary_print_rating_menu($entryid, $userid, $scale) {
     static $strrate;
 
     if (!$rating = get_record("glossary_ratings", "userid", $userid, "entryid", $entryid)) {
-        $rating->rating = 0;
+        $rating->rating = -999;
     }
 
     if (empty($strrate)) {
         $strrate = get_string("rate", "glossary");
     }
 
-    choose_from_menu($scale, $entryid, $rating->rating, "$strrate...");
+    choose_from_menu($scale, $entryid, $rating->rating, "$strrate...",'',-999);
+}
+
+
+function glossary_get_paging_bar($totalcount, $page, $perpage, $baseurl, $maxpageallowed=99999, $maxdisplay=20, $separator="&nbsp;", $specialtext="", $specialvalue=-1, $previousandnext = true) {
+// Returns the html code to represent any pagging bar. Paramenters are:
+//
+//  Mandatory:
+//     $totalcount: total number of records to be displayed
+//     $page: page currently selected (0 based)
+//     $perpage: number of records per page
+//     $baseurl: url to link in each page, the string 'page=XX' will be added automatically.
+//  Optional:
+//     $maxpageallowed: maximum number of page allowed.
+//     $maxdisplay: maximum number of page links to show in the bar
+//     $separator: string to be used between pages in the bar
+//     $specialtext: string to be showed as an special link
+//     $specialvalue: value (page) to be used in the special link
+//     $previousandnext: to decide if we want the previous and next links
+//
+// The function dinamically show the first and last pages, and "scroll" over pages.
+// Fully compatible with Moodle's print_paging_bar() function. Perhaps some day this
+// could replace the general one. ;-)
+
+    $code = '';
+
+    $showspecial = false;
+    $specialselected = false;
+
+    //Check if we have to show the special link
+    if (!empty($specialtext)) {
+        $showspecial = true;
+    }
+    //Check if we are with the special link selected
+    if ($showspecial && $page == $specialvalue) {
+        $specialselected = true;
+    } 
+
+    //If there are results (more than 1 page)
+    if ($totalcount > $perpage) {
+        $code .= "<center>";
+        $code .= "<p>".get_string("page").":";
+
+        $maxpage = (int)(($totalcount-1)/$perpage);
+
+        //Lower and upper limit of page
+        if ($page < 0) {
+            $page = 0;
+        }
+        if ($page > $maxpageallowed) {
+            $page = $maxpageallowed;
+        }
+        if ($page > $maxpage) {
+            $page = $maxpage;
+        }
+
+        //Calculate the window of pages
+        $pagefrom = $page - ((int)($maxdisplay / 2));
+        if ($pagefrom < 0) {
+            $pagefrom = 0;
+        }
+        $pageto = $pagefrom + $maxdisplay - 1;
+        if ($pageto > $maxpageallowed) {
+            $pageto = $maxpageallowed;
+        }
+        if ($pageto > $maxpage) {
+            $pageto = $maxpage;
+        }
+
+        //Some movements can be necessary if don't see enought pages
+        if ($pageto - $pagefrom < $maxdisplay - 1) {
+            if ($pageto - $maxdisplay + 1 > 0) {
+                $pagefrom = $pageto - $maxdisplay + 1;
+            }
+        }
+
+        //Calculate first and last if necessary
+        $firstpagecode = '';
+        $lastpagecode = '';
+        if ($pagefrom > 0) {
+            $firstpagecode = "$separator<a href=\"{$baseurl}page=0\">1</a>";
+            if ($pagefrom > 1) {
+                $firstpagecode .= "$separator...";
+            }
+        }
+        if ($pageto < $maxpage) {
+            if ($pageto < $maxpage -1) {
+                $lastpagecode = "$separator...";
+            }
+            $lastpagecode .= "$separator<a href=\"{$baseurl}page=$maxpage\">".($maxpage+1)."</a>";
+        }
+
+        //Previous
+        if ($page > 0 && $previousandnext) {
+            $pagenum = $page - 1;
+            $code .= "&nbsp;(<a  href=\"{$baseurl}page=$pagenum\">".get_string("previous")."</a>)&nbsp;";
+        }
+
+        //Add first
+        $code .= $firstpagecode;
+
+        $pagenum = $pagefrom;
+
+        //List of maxdisplay pages
+        while ($pagenum <= $pageto) {
+            $pagetoshow = $pagenum +1;
+            if ($pagenum == $page && !$specialselected) {
+                $code .= "$separator$pagetoshow";
+            } else {
+                $code .= "$separator<a href=\"{$baseurl}page=$pagenum\">$pagetoshow</a>";
+            }
+            $pagenum++;
+        }
+
+        //Add last
+        $code .= $lastpagecode;
+
+        //Next
+        if ($page < $maxpage && $page < $maxpageallowed && $previousandnext) {
+            $pagenum = $page + 1;
+            $code .= "$separator(<a href=\"{$baseurl}page=$pagenum\">".get_string("next")."</a>)";
+        }
+
+        //Add special
+        if ($showspecial) {
+            $code .= '<br />';
+            if ($specialselected) {
+                $code .= $specialtext;
+            } else {
+                $code .= "$separator<a href=\"{$baseurl}page=$specialvalue\">$specialtext</a>";
+            }
+        }
+
+        //End html
+        $code .= "</p>";
+        $code .= "</center>";
+    }
+
+    return $code;
 }
 
 ?>
