@@ -1,4 +1,4 @@
-<?PHP // $Id: mysql.php,v 1.10 2004/02/20 16:03:04 moodler Exp $
+<?PHP // $Id: mysql.php,v 1.10.8.1 2004/11/21 20:37:31 mjollnir_ Exp $
 
 function survey_upgrade($oldversion) {
 // This function does anything necessary to upgrade
@@ -177,6 +177,15 @@ function survey_upgrade($oldversion) {
         modify_database("", "INSERT INTO prefix_log_display VALUES ('survey', 'update', 'survey', 'name');");
     }
 
+    if ($oldversion < 2004060401) {
+        modify_database('','ALTER TABLE prefix_survey ADD INDEX course (course);');
+        modify_database('','ALTER TABLE prefix_survey_analysis ADD INDEX survey (survey);');
+        modify_database('','ALTER TABLE prefix_survey_analysis ADD INDEX userid (userid);');
+        modify_database('','ALTER TABLE prefix_survey_answers ADD INDEX userid (userid);');
+        modify_database('','ALTER TABLE prefix_survey_answers ADD INDEX survey (survey);');
+        modify_database('','ALTER TABLE prefix_survey_answers ADD INDEX question (question);');
+    }
+
     return true;
 }
 
